# We performed a survey among surgeons specialized in hip and knee arthroplasty and members of the 
# German Arthroplasty Society (AE – Arbeitsgemeinschaft für Endoprothetik) – Germany’s largest and leading society of hip and knee arthroplasty surgeons, who attended the annual AE Meeting in December 2019. 
# The original questionnaire was designed in German. Original questions are stated and are translated to English below to provide wider access.
# Figures plotted for publication in T. Vu-han, C. Gwinner, C. Perka, S. Hardt: 
# NA is "not available"
# Code written by Tu-Lan Vu-Han, Centrum für muskuloskeletale Chirurgie (CMSC) Charité University Berlin 

library(ggplot2)
library(ggthemes)
library(dplyr)

########################### HELPER FUNCTIONS##########################

multipleChoice <- function(choices,col) {
  d <- data.frame(var=choices)
  lev <- levels(factor(d$var))
  lev <- unique(unlist(strsplit(lev, ",")))
  mnames <- gsub(" ", "_", paste(col, lev, sep = "."))
  result <- matrix(data = "0", nrow = length(d$var), ncol = length(lev))
  char.var <- as.character(d$var)
  for (i in 1:length(lev)) {
    result[grep(lev[i], char.var, fixed = TRUE), i] <- "1"
  }
  result <- data.frame(result, stringsAsFactors = TRUE)
  colnames(result) <- mnames
  colnames(d) <- col
  d <- cbind(d,result)
  return(d)
}

multipleChoiceExp <- function(choices,col,lvls) {
  d <- data.frame(var=choices)
  lev <- levels(factor(d$var))
  lev <- unique(unlist(strsplit(lev, ",")))
  lev <- lvls # dummy fix to provide levels
  mnames <- gsub(" ", "_", paste(col, lev, sep = "."))
  result <- matrix(data = "0", nrow = length(d$var), ncol = length(lev))
  char.var <- as.character(d$var)
  for (i in 1:length(lev)) {
    result[grep(lev[i], char.var, fixed = TRUE), i] <- "1"
  }
  result <- data.frame(result, stringsAsFactors = TRUE)
  colnames(result) <- mnames
  colnames(d) <- col
  d <- cbind(d,result)
  return(d)
}

sumFeature <- function(df,col) {
  vars <- col
  ret = as.table(sapply(df[,vars], function(v) {
    sel <- as.numeric(v==1)
    sum(sel)
  }))
  return(ret) 
}


# prefix for path
path <- "~/orchid/"
# path <- dirname(sys.frame(1)$ofile)

# General formatting string for plots
customPlot <- list(
  scale_colour_tableau(),
  theme(plot.title = element_text(face="bold", hjust = 0.5)
  ) 
)

customPlotHist <- list(
  geom_text(aes(y = (..count..),label = ifelse((..count..)==0,"",scales::percent((..count..)/sum(..count..)))), stat="count", vjust=-0.5)
)

############End Helper Functions################################################################################################################################
################################################################################################################################################################

# Layout: 
# Q1 General Questions
# Q3 Specific questions to knee arthroplasty 
# Q5 Recommendations for type of activity after TKA

################################################################################################################################################################
################################################################################################################################################################

# Q1.1: (Survey Paticipant) "In welchem Jahr ca. haben Sie ihre Approbation erhalten?" 
# "In which year did you receive your Approbation?" 
# a = "vor 1980"
#     "before 1980"
# b = "1980-1990"
#     "1980-1990"
# c = "1990-2000"
#     "1990-2000"
# d = "2000-2010"
#     "2000-2010"
# e = "2010-2020"
#     "2010-2020"
# Convention: if multiple answers earliest reported
# Convention: if exactly on boundary always in earliest

Q1_1 <- factor(
  c('c','d','c','c','e','e','c','b','d','d',
    'd','d','c','d','b','c','c','c','b','c',
    'e','d','d','d','b','d','d','c','b','d',
    'c','c','d','a','b','b','c','d','d','c',
    NA,'b','b','e','d','d','e','c','d','b',
    'c','d','c','c','b','c','c','c','b','b',
    'c','c','b','c','c','d','c','c','b','b',
    'b','d','d','b','e','b','d','c','d','c',  
    'c','b','d','e','a','b','a','e','d','d',
    'e','e','e','d','d','e','e','c','d','d',
    'c'
    ),
  order = TRUE, 
  levels=c('a','b','c','d','e'), 
  labels=c('before 1980', '1980 - 1990', '1990 - 2000', '2000 - 2010', '2010 - 2020')
  )

data.frame(Q1_1)
################################################################################################################################################################
################################################################################################################################################################

# Q1.2: (Survey Participant) "Wie hoch schätzen Sie ihre eigene sportliche Aktivität ein?" 
# "How high do you rate your own athletic activity?"
# a = "sehr hoch, ich mache täglich Sport"
#     "very high, I do sports daily"
# b = "hoch, ich mache mehrmals die Woche Sport"
#     "high, I do sports multiple times a week"
# c = "mittel, ich mache ab und zu Sport"
#     "medium, I do sports every now and then"
# d = "niedrig, ich mache gar kein Sport"
#     "low, I do not do sports"

Q1_2 <- factor(
  c('c','c','c','c','b','b','b','b','d','b',
    'b','b','c','c','c','c','b','b','b','c',
    'b','b','b','b','c','b','c','b','b','d',
    'b','b','c','c','b','b','a','b','b','b',
    'c','b','b','b','b','c','b','d','b','c',
    'b','c','b','b','c','d','b','c','c','b',
    'c','b','b','b','c','a','c','c','b','b',
    'c','b','a','b','b','c','c','c','c','b',
    'c','b','b','c','b','c','c','b','b','c',
    'b','c','b','c','c','b','c','b','b','c', 
    'b'
  ),
  order = TRUE, 
  levels=c('a','b','c','d'), 
  # labels=c('very high (daily)', 'high (multiple/week)', 'medium (once/week)', 'low (none)')
  labels=c('very high', 'high', 'medium', 'low')
)

data.frame(Q1_2)
################################################################################################################################################################
################################################################################################################################################################

# Q1.3: "Gehört die Frage nach der sportlichen Aktivität des Patienten vor Endoprothesenersatz zu ihrem Standardfragekatalog?"
# "Is the question of the patient's sporting activity before joint replacement part of your standard patient interview?
# a = "Ja"
#     "Yes"
# b = "Nein"
#     "No"
# c = "Weiß nicht"
#     "I don't know"
# d = "Egal"
#     "It does not matter"

Q1_3 <- factor(
  c('a','a','a','b','a','b','a','a','a','b',
    'a','a','a','a','a','b','a','a','a','b',
    'a','b','a','a','a','a','a','a','a','b',
    'a','b','a','a','b','a','a','a','a','a',
    NA,'a','a','b','a','a','a','a','a','a',
    'a','a','a','a','a','a','a','a','b','a',
    'a','a','a','a','a','a','a','a','a','a',
    'a','a','a','a','b','b','b','a','a','b',
    'b','a','a','b','a','a','b','a','a','b',
    'a','a','a','b','a','a','a','a','b','a', 
    'a'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('Yes', 'No', 'I do not know', 'Does not matter')
)

data.frame(Q1_3)
################################################################################################################################################################
################################################################################################################################################################

# Q1.4: "Welche präoperativen Parameter sind für Sie hinsichtlich der postoperativen Sportfähigkeit in der Beurteilung relevant?"
# "Which preoperative parameters are relevant for you with regard to postoperative sporting ability in the assessment?"
# a = "Alter"
#     "Age"
# b = "Geschlecht"
#     "Gender"
# c = "BMI"
#     "Body mass index"
# d = "Muskelmasse"
#     "Muscle mass"
# e = "Koordination/Ausübung der Sportart vor der geplanten Operation"
#     "Coordination/Experience of the sport before planned surgery"
# f = "Knochendichte"
#     "Bone density"
# g = "Neurologische Nebenerkrankungen"
#     "Neurologic precondition "
# h = "Rheumatologische Grunderkrankungen"
#     "Rheumatologic precondition"

##### Multiple Choice Q1.4
choicesQ1_4 = 
  c('d,e', 'a,c,e', 'e', 'a,b,e,g,h', 'a,b,c,e,g', 'a,c,e', 'a,c,d,e,f,g', 'e', 'a,c,d,e', 'a,b,c,d,e,f,g', 
    'e', 'e,g', 'a,c,d,e', 'a,c,e,g', 'e,g', 'a,d,e', 'a,c,e,f', 'e,g', 'a,c,g', 'a,d,e,g', 
    'a,c,d,e,f,g,h', 'a,e', 'a,c,g', 'a,c,d,e,g', 'a,c,e,g,h', 'e', 'c,e,g,f', 'a,b,c,d,e,f,g,h', 'e', 'a,c',
    'a,b,c,d,e,g', 'a,c,e', 'e', 'a,d,e', 'e', 'a,c,d,e', 'd,e,g,h', 'a,c,d,g', 'a,c,e', 'a,b,c,e',
    'e', 'e', 'd,e,g', 'a,c,e,g', 'e', 'a,c,g', 'a,b,c,d,e,f,g,h', 'a,c,d,e,g', 'a,b,c,d,e,f,g,h', 'e',
    'a,b,c,d,e,g', 'a,c,d,e', 'c,d,e,f,g,h', 'd,e,g,h', 'e,f,g', 'e', 'a,c,d,e,f,g,h', 'a,b,c,e', 'a,e,g', 'a,b,c,d,e,f,g',
    'c,e', 'a,c,e', 'c,e,g', 'a,c,d,e', 'a,c,d,e', 'a,c,d,e', 'e', 'c,e,f,g,h', 'a,b,c,f,h', 'e',
    'a,b,c,e,g', 'a,c,e', 'a,b,c,d,e,f,g,h', 'a,c,e,f','a,c,d,e,g,h', 'a,c,e', 'e', 'a,b,c,e,g,h', 'b,c,d,e', 'a,e',  
    'a,c,d,e,g', 'e', 'a,c,e,g', 'a,c,e', 'a,b,c,d,e,f,g,h', 'a,b,c,e', 'a,c,d,e,h', 'a,c,d,e,f,g,h', 'a,c,e', 'a,c,e,f,g,h',
    'a,b,c,d,e', 'a,c,e', 'e,g', 'a,c,d,f', 'c,d,e,f,g,h', 'c,e,g', 'c,e,f','b,e,g','e,g','a,b,c,d,e,g,h', 
    'd,e,f,g,h'
  )

Q1_4_df = multipleChoice(choicesQ1_4,"Q1.4")
Q1_4_freq = sumFeature(Q1_4_df, c("Q1.4.a","Q1.4.b","Q1.4.c","Q1.4.d","Q1.4.e","Q1.4.f","Q1.4.g","Q1.4.h"))

Q1_4_vec = as.vector(Q1_4_freq)

groupNames = c("Age","Gender","BMI","Muscle mass","Coordination*","Bone density","Neurological D.","Rheumatolog D.")
tempLabels = c("Type","Count")

Q1_4_df = data.frame(groupNames, Q1_4_vec)
colnames(Q1_4_df) = tempLabels

Q1_4_df = Q1_4_df[order(Q1_4_df["Type"]),]
row.names(Q1_4_df) <- 1:nrow(Q1_4_df)

Q1_4_df$Type <- factor(Q1_4_df$Type, levels=Q1_4_df$Type[order(Q1_4_df["Count"],decreasing = FALSE)])
row.names(Q1_4_df) <- 1:nrow(Q1_4_df)
print(Q1_4_df$Type)

#Fig. 1a Preoperative parameters that influence athletic capacity after THA
# Q1.4 HP: Plotting "Preoperative Parameters" 
ggp <- ggplot(Q1_4_df,aes(x=Type, y=Count), position="stack", stat='identity') + xlab("Parameters") + 
  ylab("Counts") + labs(fill = "Sport") + ggtitle("Preoperative Parameters") + customPlot
ggp + geom_col() + scale_fill_grey(start=0.8, end=0.2) + theme(axis.text.y = element_text(angle = 0, hjust = 1, size=12)) + 
  coord_flip() + labs(tag="A") + geom_text(aes(label = Count), hjust=- 0.5, size=5) + 
  scale_y_discrete(expand = expansion(mult=c(.02,.1))) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q1_4-Histogram.pdf"), width=6, height=5)
################################################################################################################################################################
################################################################################################################################################################

# Q1.5: "Frage nach Hauptrisiken durch Sport "Welches ist Ihrer Einschätzung nach das Hauptrisiko durch Sport nach Implantation einer Endoprothese? (maximal 2 Nennungen)"
# "What do you think is the main risk from sport after implantation of an endoprosthesis? (Maximum 2 answers)"
# a = "Luxation"
#     "Joint dislocation"
# b = "Periprothetische Fraktur"
#     "Periprosthetic fracture"
# c = "Vorzeitige Prothesenlockerung"
#     "Implant loosening"
# d = "PE-Abrieb"
#     "Polyethylene-wear"
# e = "Periprothetische Infektion"
#     "Periprosthetic infection"
# f = "Osteolyse"
#     "Osteolysis"
# g = "Materialbruch"
#     "Mmaterial breach"
# h = "Bandruptur"
#     "Tendon rupture"
# i = "Andere"
#     "Other"

##### Multiple Choice Q1.5
choicesQ1_5 = 
  c('a,b', 'b,d', 'b,c', 'a,b,d', 'a,d', 'a', 'b,c', 'b', 'a,c', 'c,d', 
    'a,d', 'a,d', 'a,b', 'd', 'b,h', 'b,h', 'b', 'a,b', 'b,c', 'c,i', 
    'd', 'b,c', 'a,b', 'b,c,d,h', 'a', 'd', 'a,b', 'b,d', 'c,h', 'a,b',
    'b,i', 'a,b', 'b,c', 'a,b', 'b', 'd,h', 'b,d,h', 'a,b', 'a,c', 'b,d,h',
    'b', 'a,b', 'b', 'c,d', 'a', 'a,d', 'a,b', 'd,g', 'c', 'b',
    'c,d', 'a,b', 'b,c', 'b,d', 'a,b', 'a', 'c', 'a,b', 'a,h', 'b,d',
    'b,c', 'a,b', 'c,d', 'b,h', 'b,h', 'a,b,h', 'b,h', 'd,g', 'c,e', 'd',
    'a,b', 'a,b', 'a,b,c,d,g', 'a,c,f','b,d', 'c,d', 'c,d', 'b,c', 'c,d', 'b,c',  
    'a,b', 'd,g', 'b,c,d', 'a,b', 'c,d', 'a,b,c', NA, 'c,d', 'a,b', 'a,d',
    'a,h', 'a,c', 'c,d', 'b,c,d,g', 'c,d', 'b,c', 'a,b', 'b,i', 'a,b,i','b,c',
    'c,d'
  )

Q1_5_df = multipleChoice(choicesQ1_5,"Q1.5")
Q1_5_freq = sumFeature(Q1_5_df, c("Q1.5.a","Q1.5.b","Q1.5.c","Q1.5.d","Q1.5.e","Q1.5.f","Q1.5.g","Q1.5.h","Q1.5.i"))

#ID Comments: 
#ID_20= Andere (i): Überbeanspruchung Schmerz = "Overload pain"

Q1_5_df = multipleChoice(choicesQ1_5,"Q1.5")
Q1_5_freq = sumFeature(Q1_5_df, c("Q1.5.a","Q1.5.b","Q1.5.c","Q1.5.d","Q1.5.e","Q1.5.f","Q1.5.g","Q1.5.h","Q1.5.i"))

Q1_5_vec = as.vector(Q1_5_freq)

groupNames = c("Dislocation"," Periprosthetic fracture"," Implant loosening", " Polyethylene-wear"," Periprosthetic infection"," Osteolysis"," Material breach"," Tendon rupture","Other")
tempLabels = c("Type","Count")

Q1_5_df = data.frame(groupNames, Q1_5_vec)
colnames(Q1_5_df) = tempLabels

Q1_5_df = Q1_5_df[order(Q1_5_df["Type"]),]
row.names(Q1_5_df) <- 1:nrow(Q1_5_df)

# Q1.5 Re-order the risks by frequency 
Q1_5_df$Type <- factor(Q1_5_df$Type, levels=Q1_5_df$Type[order(Q1_5_df["Count"],decreasing = FALSE)])
row.names(Q1_5_df) <- 1:nrow(Q1_5_df)
print(Q1_5_df$Type)

#Fig 1b Risks associated with sports after joint arthroplasty
# Q1.5 Plot risks associated with sports after joint arthroplasty
ggp <- ggplot(Q1_5_df,aes(x=Type, y=Count), position="stack", stat='identity') + xlab("Risks") + 
  ylab("Counts") + labs(fill = "Sport") + ggtitle("Risks Associated with Sports after Arthroplasty") + customPlot
ggp + geom_col() +
  scale_fill_grey(start=0.8, end=0.2) + coord_flip() + theme(axis.text.y = element_text(angle = 0, hjust = 1, size =12)) + 
  geom_text(aes(label = Count), hjust=-0.5, size=5) + scale_y_discrete(expand = expansion(mult=c(.02,.1))) + labs(tag="B") + theme(
    panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                    size = 2, linetype = "solid"),
    panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                    colour = "grey75"), 
    panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                    colour = "grey75")
  )
ggsave(paste(path, "Q1_5-Histogram.pdf"), width=8, height=5)
################################################################################################################################################################
################################################################################################################################################################

# Q3.1 "Für wie wichtig halten Sie sportliche Aktivität nach Knieendoprothesenersatz?"
# "How important do you think sporting activity after knee replacement surgery?"
# a = "sehr wichtig"
#     "very important"
# b = "wichtig"
#     "important"
# c = "nicht wichtig"
#     "not important"
# d = "egal"
#     "does not matter"

Q3_1<- factor(
  c('b', 'b', 'a', 'a', 'a', 'a', 'b', 'a', 'b', 'b', 
    NA, 'b', 'b', 'a', 'a', 'c', 'a', 'a', 'a', 'c', 
    'b', 'a', 'a', 'b', 'b', 'b', 'a', 'b', 'b', 'b',
    'b', 'c', 'b', NA, 'a', 'a', 'a', NA, 'b', 'b',
    'b', 'b', 'a', 'b', 'b', 'b', 'b', 'c', 'b', 'b',
    'c', 'b', 'a', 'd', 'b', 'b', 'b', 'b', 'd', 'b',
    'b', 'b', 'c', 'a', 'a', 'a', 'b', 'b', 'a', 'b',
    'b', 'a', 'a', 'a', 'b', NA, 'b', 'a', 'b', 'b',  
    'b', 'a', 'b', NA, 'b', 'b', 'b', 'a', 'b', 'c',
    'a', 'b', 'b', 'c', 'b', 'b', 'a', 'b', 'b', 'c', 
    'b'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('very important', 'important', 'not important', 'does not matter')
)

data.frame(Q3_1)
################################################################################################################################################################
################################################################################################################################################################

# Q3.2 "Glauben Sie, dass sportliche Aktivität die Haltbarkeit einer Knieendoprothese negativ beeinflusst (Standzeit reduziert)?"
# "Do you think that physical activity has a negative impact on the durability of a knee arthroplasty (reduced lifespan)?"
# a = "Ja"
#     "Yes"
# b = "Nein"
#     "No"
# c = "Weiß nicht"
#     "Do not know"
# d = "Egal"
#     "Does not matter"

Q3_2<- factor(
  c('b', 'a', 'b', 'a', 'b', 'b', 'a', 'b', 'a', 'a', 
    'a', 'c', 'b', 'a', 'b', 'b', 'c', 'b', 'c', 'a', 
    'c', 'a', 'b', 'a', 'b', 'a', 'b', 'c', 'b', 'a',
    'a', 'b', 'a', 'b', 'b', 'b', 'b', NA, 'a', 'c',
    'b', 'c', 'c', 'a', 'b', 'b', 'b', 'a', NA, 'a',
    'a', 'a', 'a', 'a', 'b', 'b', 'c', 'b', 'b', 'a',
    'a', 'b', 'a', 'b', 'b', 'b', 'b', 'b', 'b', 'a',
    'a', 'b', 'a', 'b', 'b', NA, 'b', 'b', 'b', 'a',  
    'c', 'b', 'c', NA, 'c', 'c', 'b', 'a', 'b', 'a',
    'b', 'b', 'c', 'a', 'a', 'c', 'b','b','b', 'b', 
    'b'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('yes', 'no', 'do not know', 'does not matter')
)
#ID comments:
#ID_7: "Kommt au den Sport an" = "depends on the type of sport"
#ID_49: "Je nach Sportart" = "depending on the type of sport"

data.frame(Q3_2)
################################################################################################################################################################
################################################################################################################################################################

# Q3.3: "Glauben Sie, dass die sportliche Aktivität die Funktion der Knieendoprothese positiv beeinflusst?"
# "Do you think that physical activity has a positive impact on the durability of a hip arthroplasty (reduced lifespan)?"
# a = "Ja"
#     "Yes"
# b = "Nein"
#     "No"
# c = "Weiß nicht"
#     "Do not know"
# d = "Egal"
#     "Does not matter"

Q3_3<- factor(
  c('b', 'b', 'b', 'a', 'a', 'a', 'a', 'a', 'a', 'a', 
    'a', 'c', 'a', 'a', 'a', 'b', 'a', 'b', 'a', 'b', 
    'a', 'a', 'a', 'a', 'a', 'c', 'a', 'a', 'a', 'a',
    'c', 'b', 'a', 'c', 'a', 'a', 'a', 'a', NA, 'a',
    'a', 'c', 'a', 'a', 'a', 'b', 'a', 'b', 'a', 'a',
    'b', 'b', 'a', 'c', 'c', 'a', 'a', 'b', 'a', 'a',
    'a', 'a', 'b', 'a', 'a', 'a', 'a', 'a', 'a', 'a',
    'a', 'a', 'a', 'a', 'a', NA, 'a', 'a', 'a', 'a',  
    'a', 'a', 'a', NA, 'a', NA, 'a', 'a', 'c', 'a',
    'a', 'a', 'a', 'b', 'a', 'c', 'a','a','b', 'a', 
    'a'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('yes', 'no', 'do not know', 'does not matter')
)
#ID comments: None

data.frame(Q3_3)
################################################################################################################################################################
################################################################################################################################################################

# Q3.4 "Die Belastung, welcher sich Patienten mit einer Knieendoprothese aussetzen ist in der Regel..."
#"The burden that patients with a knee arthroplasty expose themselves to is usually ..."
# a = "Viel zu hoch"
#     "Way too high"
# b = "Etwas zu hoch"
#     "A little too high"
# c = "Genau richtig"
#     "Just right"
# d = "Zu niedrig"
#     "Too low"
# d = "Viel zu niedrig"
#     "Way too low"

Q3_4<- factor(
  c('d', 'c', 'd', 'b', 'd', 'd', 'c', 'd', 'b', 'd', 
    'c', 'd', 'c', 'd', 'd', 'c', 'd', NA, 'b', 'c', 
    'd', 'd', 'b', NA, 'd', 'd', 'd', 'c', 'd', 'c',
    'c', 'c', 'b', 'c', 'c', 'b', 'd', 'd', NA, 'd',
    'd', 'c', 'd', 'b', 'c', 'c', 'd', 'c', 'b', 'c',
    'a', 'c', 'b', 'c', 'd', 'c', 'd', 'c', 'd', 'd',
    'b', 'd', 'c', 'c', 'c', 'd', 'c', 'c', 'd', 'c',
    NA, 'd', 'b', 'b', 'd', NA, 'c', 'd', 'b', 'd',  
    'b', 'd', 'c', NA, 'b', 'd', 'c', 'd', 'b', 'c',
    'd', 'd', 'c', 'c', 'e', 'd', 'd','c','c', 'd', 
    'd'
  ),
  order = TRUE, 
  levels=c('a','b','c','d','e'), 
  labels=c('way too high', 'little too high', 'just right', 'too low', 'way too low')
)

#ID comments:
#ID_26 Die Frage ich ungenügend präzise. z.B. Pat. mit BMI >35 haben sofort eine hohe Belastung als die dünnen. Sportezogen? Dann eher zu niedrig. = "I find this question insufficiently precise. for example, patients with a BMI >35 have a direct high stress on the implant compared to thin people. sports-wise, rather too low."
#ID_71 NA-jenach Patient = "NA, depends on the patient"

data.frame(Q3_4)
################################################################################################################################################################
################################################################################################################################################################

# Q3.5 "Wie führen Sie die Fehlschläge von Knieendoprothesen auf Überlastung bzw. Sport zurück?"
# "How often do you attribute knee arthroplasty failures to stress overload or sports?"
# a = "In mehr als 50% der Revisionen"
#     "In more than 50% of revision surgeries"
# b = "In mehr als 25% der Revisionen"
#     "In more than 25% of revision surgeries"
# c = "In mehr als 10% der Revisionen"
#     "In more than 10% of revision surgeries"
# d = "In mehr als 5% der Revisionen"
#     "In more than 5% of revision surgeries"
# e = "In mehr als 1% der Revisionen"
#     "In more than 1% of revision surgeries"
# f = "In weniger als 1% der Revisionen"
#     "In less than 1% of revision surgeries"

Q3_5<- factor(
  c('e', 'd', 'f', NA, 'e', 'f', 'e', 'f', 'e', 'e', 
    'f', 'e', 'e', 'f', 'f', 'e', 'e', 'd', 'd', 'e', 
    'f', 'f', 'f', 'c', 'f', NA, 'e', 'e', 'e', 'f',
    'e', 'f', 'd', 'd', 'd', 'd', 'e', 'f', NA, 'e',
    'f', 'd', 'e', 'e', 'f', 'f', 'f', 'd', 'd', 'e',
    'b', 'd', 'c', 'e', 'e', 'f', 'd', 'f', 'f', 'f',
    'b', 'f', 'd', 'c', 'c', 'f', 'f', 'e', 'd', 'd',
    NA, 'e', 'c', 'c', 'f', NA, 'f', 'f', 'c', 'f',  
    'e', 'f', 'f', NA, 'f', 'f', 'f', 'd', 'f', 'd',
    'd', 'e', 'f', 'f', 'f', 'd', 'f','e','f', 'f', 
    'e'
  ),
  order = TRUE, 
  levels=c('a','b','c','d','e', 'f'), 
  labels=c('>50%', '>25%', '>10%', '>5%', '>1%', '<1%')
)
#ID comments: NONE.

data.frame(Q3_5)
################################################################################################################################################################
################################################################################################################################################################

# Q3.6 "Hat ein hoher sportlicher Anspruch Einfluss auf die Wahl ihres operativen Zugangsweges? Wenn ja, welchen wählen Sie?"
# "Does a high athletic standard influence the choice of your surgical access route? If yes, which one do you choose?"
# a = "Ja, medial parapatellär"
#     "Yes, medial parapetallar"
# b = "Ja, subvastus"
#     "Yes, subvastus"
# c = "Ja, midvastus"
#     "Yes, midvastus"
# d = "Nein"
#     "No"

Q3_6<- factor(
  c('d', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'b', 'd', 'd', 
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'a', 'a', 'b', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'd', NA, 'd', 'e', 'd', 'd',  
    'd', 'd', 'd', NA, 'd', 'd', 'b', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'd', 'd', 'd','a','d', 'd', 
    'd'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('medial\n parapatellar', 'subvastus', 'midvastus', 'none')
)

data.frame(Q3_6)
################################################################################################################################################################
################################################################################################################################################################

#3.7 "Hat ein hoher sportlicher Anspruch Einfluss auf das angestrebte Alignment? Wenn ja, welches? "
#"Does a high level of sporting ability influence the desired alignment? If yes, which one?"
# a = "Ja, mechanisches Alignment"
#     "Yes, mechanical alignment"
# b = "Ja, kinematisches Alignment"
#     "Yes, kinematic alignment"
# c = "Ja, anatomisches Alignment, residueller Varus- bzw. Valgus"
#     "Yes, anatomical alignment, residual varus- or valgus"
# d = "Nein"
#     "No"

Q3_7<- factor(
  c('d', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 
    'b', 'd', 'd', 'c', 'd', 'd', NA, 'd', 'd', 'd', 
    'd', 'd', 'd', 'd', 'd', 'd', 'c', 'd', 'd', NA,
    'd', 'd', 'd', 'b', 'd', 'a', 'c', 'd', 'd', 'b',
    'd', 'd', 'd', 'b', 'd', 'd', 'a', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'a', 'd', 'b', 'a', 'd', 'd',
    'd', 'd', 'd', 'c', 'c', 'c', 'c', 'd', 'd', 'b',
    NA, 'd', 'd', 'c', 'd', NA, 'd', 'e', 'b', 'd',  
    'd', 'd', 'd', NA, 'd', 'd', 'd', 'a', 'd', 'b',
    'c', 'd', 'd', 'd', 'd', 'd', 'd','a','d', 'd', 
    'd'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('mechanical', 'kinematic', 'anatomical', 'none')
)
#ID comments: NONE

data.frame(Q3_7)

################################################################################################################################################################
################################################################################################################################################################

#3.8 "Ziehen Sie bei hoher sportlicher Beansprchung eine Unikondyläre Schlittenprothese zu einer bikondylären vor?"
# "Do you prefer a unicondylar sled prosthesis to a bicondylar one in case of high physical demands?"
# a = "Ja"
#     "Yes"
# b = "Nein"
#     "No"

Q3_8<- factor(
  c('a', 'b', 'b', 'b', 'a', 'b', 'b', 'b', 'a', 'b', 
    'b', 'b', 'b', 'b', 'b', 'a', 'b', 'b', 'b', 'b', 
    'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', NA,
    'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b',
    'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b',
    'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b',
    'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'a', 'a',
    NA, 'a', 'b', 'a', 'b', NA, 'b', 'b', 'b', 'a',  
    'b', 'a', 'b', NA, 'b', 'b', 'b', 'b', 'b', 'b',
    'b', 'a', 'b', 'b', 'b', 'b', 'b','b','b', 'a', 
    'b'
  ),
  order = FALSE, 
  levels=c('a','b'), 
  labels=c('bicondylar', 'unicondylar')
)
#ID comments: NONE

data.frame(Q3_8)
################################################################################################################################################################
################################################################################################################################################################

#Q3.9 "Beeinflusst das Design einer Knie-TEP die Sportfähigkeit? Wenn ja, welches wählen Sie?"
#"Does the design of a knee arthroplasty affect athletic ability? If so, which design do you choose?"
# a = "Single-Radius"
#     "single-radius"
# b = "Multi-Radius"
#     "multi-radius"
# c = "J-Curve"
#     "J-Curve"
# d = "Medial-pivot"
#     "medial-pivot"
# e = "andere"
#     "Other"

Q3_9<- factor(
  c('c', 'c', 'b,c', 'b,d', 'e', 'b', 'f', 'f', 'f', 'f', 
    'f', 'b', 'c', 'e', 'c', NA, 'e', 'f', 'f', 'f', 
    'f', 'f', 'f', 'f', 'c', 'f', 'c', 'b', 'e', 'f',
    'f', 'f', 'b', NA, 'b', 'd', 'b', 'b', NA, 'f',
    'f', 'f', 'f', 'b', 'b', 'f', NA, 'a', 'e', 'e',
    'f', 'f', 'e', 'f', 'f', 'f', 'f', 'f', 'f', 'b,c',
    'b', 'f', 'f', 'f', 'f', 'f', 'f', 'f', 'f', 'b',
    NA, 'b', 'f', NA, 'c', NA, 'f', 'f', 'f', 'f',  
    'f', 'f', 'f', NA, 'f', 'f', 'f', 'b', 'f', 'a',
    'c', 'f', 'c', 'f', 'f', 'b,c', 'b','f','f', 'b',
    'f'
  ),
  order = FALSE, 
  levels=c('a','b','c','d','e','f'), 
  labels=c('single radius', 'multi-radius', 'J-curve', 'medial-pivot', 'other', 'none')
)
#ID comments:
#ID14_CAD-CAM
#ID50_anatomisch

data.frame(Q3_9)
################################################################################################################################################################
################################################################################################################################################################

#Q3.10 "Welchen Kopplungstyp für eine Knie-TEP empfehlen Sie bei den gewünschten sportlichen Aktivitäten des Patienten?" 
#"What type of coupling for a TKA do you recommend for the patient's desired sporting activities?"
# a = "HKB erhaltend"
#     "posterior cruciate retaining (PCR)"
# b = "HKB substituierend"
#     "posterior cruciate substituting (PCS)"
# c = "Ultrakongruent (PS Design)"
#     "Ultracongruent (posterior stabilizing design)"
# d = "Fixed bearing"
#     "Fixed bearing"
# e = "Mobile bearing"
#     "Mobile bearing"
# f = "Tibiale Stielverlängerung"
#     "Increased tibial shaft length"
# g = "Gekoppelte Prothese (Hinged)"
#     "Hinged prosthesis"

lvls = c("a","b","c","d","e","f","g")

# Q3.10.1 High-Impact 
Q3_10_1<- factor(
  c('a,d,e,f', 'a,d', 'c,d', 'a', 'a', 'a,b,d,e,f', NA, 'a', 'a,e', 'b,c,d', 
    NA, 'a,b,c,d,e', 'a,d', 'a', 'b', 'a,d', NA, 'a', 'a,e,f', 'a,d', 
    'a,d',NA, NA, 'c,e', 'a,e', NA, NA, 'a,d', 'c,d', 'a',
    'a,e', 'a', NA, NA, 'a,e', 'a,b,e', 'b,d', 'a', NA, 'a,c',
    'a', NA, 'b', 'a,d', 'e', 'a,d', 'c', 'a,d,f', 'c', 'a,d,f',
    'a,c,d', 'a', 'a', 'a', 'a,d', 'c,e', 'a', 'a', 'a,e', 'a,d',
    'b,d', 'd', NA, 'b,c,d', 'b,c,d', 'a,e', 'a,d,e', 'b', 'a,d', 'b,d',
    NA, 'a,e', 'a,e', 'a,e', 'a', NA, 'e', 'a', 'a,d', 'a,d',  
    'b', 'a,e', NA, NA, NA, 'a', 'a,e', 'a,b,d,e', NA, 'a,e',
    'a,d,e', 'a', 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b', 'a,d', 
    'a,b,c,d'
  ),
  order = FALSE, 
  levels=c('a','b','c','d','e','f','g'), 
  labels=c('PCL retaining','PCL substituting','Ultracongruent (PS Design)','Bearing: fixed', 'Bearing: mobile', 'Incr.tib.shaft length', 'Hinged TKA')
)
#ID comments:
#ID_63: "high-impact sport ungeeignet für Knie-TEP Patienten" = "High impact sports are unsuited for TKA patients"

data.frame(Q3_10_1)

##### Multiple Choice Q3.10.1
choicesQ3_10_1 = 
  c('a,d,e,f', 'a,d', 'c,d', 'a', 'a', 'a,b,d,e,f', NA, 'a', 'a,e', 'b,c,d', 
    NA, 'a,b,c,d,e', 'a,d', 'a', 'b', 'a,d', NA, 'a', 'a,e,f', 'a,d', 
    'a,d',NA, NA, 'c,e', 'a,e', NA, NA, 'a,d', 'c,d', 'a',
    'a,e', 'a', NA, NA, 'a,e', 'a,b,e', 'b,d', 'a', NA, 'a,c',
    'a', NA, 'b', 'a,d', 'e', 'a,d', 'c', 'a,d,f', 'c', 'a,d,f',
    'a,c,d', 'a', 'a', 'a', 'a,d', 'c,e', 'a', 'a', 'a,e', 'a,d',
    'b,d', 'd', NA, 'b,c,d', 'b,c,d', 'a,e', 'a,d,e', 'b', 'a,d', 'b,d',
    NA, 'a,e', 'a,e', 'a,e', 'a', NA, 'e', 'a', 'a,d', 'a,d',  
    'b', 'a,e', NA, NA, NA, 'a', 'a,e', 'a,b,d,e', NA, 'a,e',
    'a,d,e', 'a', 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b', 'a,d', 
    'a,b,c,d'
  )

Q3_10_1_df = multipleChoiceExp(choicesQ3_10_1,"Q3.10.1",lvls)
Q3_10_1_freq = sumFeature(Q3_10_1_df, c("Q3.10.1.a","Q3.10.1.b","Q3.10.1.c","Q3.10.1.d","Q3.10.1.e","Q3.10.1.f","Q3.10.1.g"))

# Q3.10.2 Low-Impact 
Q3_10_2<- factor(
  c('b', 'a,d', 'c,e', 'a', NA, 'c,g', 'a,d', 'a', 'a,e', 'a,c,d', 
    'a', 'a,b,c,d,e,f', 'a,b,c,d', 'a', 'b', 'a,d', NA, 'a', 'b,c,d,g', 'a,d', 
    'a,d', NA, 'a,b,c,d,e,f', 'c,e', NA, 'a,b,c,d,e', 'a,b,c,d,e,f,g', 'c,e', 'c,d', 'a',
    NA, 'a', 'a,b,c,d,e,f', 'a,b,c,d,e,f,g', 'a,e', 'a,b,e', 'b,d', 'a', NA, 'a,c',
    'a', 'a,b,c,d,e,f,g', 'b', 'a,d', 'e', 'a,d', 'c', 'a,d', 'c', 'a,d,f',
    'a,c,d', 'a', 'a', 'a', 'a,d', 'c,e', 'a', 'a', 'a,d', 'a,d,e',
    'a,c,e', 'a,e,f,g', 'b,d', 'b,c,d', 'b,c,d', 'a,e', 'b,c,f', 'b', 'd', 'a,e',
    NA, 'g', 'a,e', 'c', 'a', NA, 'e', 'a', 'a,b,c,d,e', 'a,d',  
    'b', 'a,c,e', 'a,b,c,d,e,f,g', NA, 'a,b,c,d,e,f,g', 'c,d', 'a,e', 'c,f', NA, 'c,d',
    'a,b,c,d,e', NA, 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b,c,d,e,g', 'a,d', 
    NA
  ),
  order = FALSE, 
  levels=c('a','b','c','d','e','f','g'), 
  labels=c('PCL retaining','PCL substituting','ultracongruent (PS Design)','fixed bearing', 'mobile bearing', 'incr. tib. shaft length','hinged')
)
#ID comments:
#ID_101"Je nach anatomischer Vorgabe bzw. Pathologie" = "depends on anatomic situation or pathology of the patient"

data.frame(Q3_10_2)
##### M Choice Q3.10.2
choicesQ3_10_2 = 
  c('b', 'a,d', 'c,e', 'a', NA, 'c,g', 'a,d', 'a', 'a,e', 'a,c,d', 
    'a', 'a,b,c,d,e,f', 'a,b,c,d', 'a', 'b', 'a,d', NA, 'a', 'b,c,d,g', 'a,d', 
    'a,d', NA, 'a,b,c,d,e,f', 'c,e', NA, 'a,b,c,d,e', 'a,b,c,d,e,f,g', 'c,e', 'c,d', 'a',
    NA, 'a', 'a,b,c,d,e,f', 'a,b,c,d,e,f,g', 'a,e', 'a,b,e', 'b,d', 'a', NA, 'a,c',
    'a', 'a,b,c,d,e,f,g', 'b', 'a,d', 'e', 'a,d', 'c', 'a,d', 'c', 'a,d,f',
    'a,c,d', 'a', 'a', 'a', 'a,d', 'c,e', 'a', 'a', 'a,d', 'a,d,e',
    'a,c,e', 'a,e,f,g', 'b,d', 'b,c,d', 'b,c,d', 'a,e', 'b,c,f', 'b', 'd', 'a,e',
    NA, 'g', 'a,e', 'c', 'a', NA, 'e', 'a', 'a,b,c,d,e', 'a,d',  
    'b', 'a,c,e', 'a,b,c,d,e,f,g', NA, 'a,b,c,d,e,f,g', 'c,d', 'a,e', 'c,f', NA, 'c,d',
    'a,b,c,d,e', NA, 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b,c,d,e,g', 'a,d', 
    NA
  )

Q3_10_2_df = multipleChoiceExp(choicesQ3_10_2,"Q3.10.2",lvls)
Q3_10_2_freq = sumFeature(Q3_10_2_df, c("Q3.10.2.a","Q3.10.2.b","Q3.10.2.c","Q3.10.2.d","Q3.10.2.e","Q3.10.2.f","Q3.10.2.g"))

# Q3.10.3 Kein Sport = No Sports
Q3_10_3<- factor(
  c('c,g', 'a', 'c,e', 'b', NA, NA, 'a,d', 'a', 'a,e', 'a,d', 
    'a', 'a,b,c,d,e,g', 'a,b,c,d', 'a', 'b', 'a,d', NA, 'a', NA, 'b,d', 
    'a,d', NA, 'g', 'c,e', NA, 'f,g', NA, 'c,e', 'c,d', 'a',
    NA, 'a', 'g', NA, 'a,e', NA, 'b,d', 'a', NA, 'a',
    'a', NA, 'b', 'a,d', 'e', 'a,d', NA, 'a,d', 'c', 'a,d,g',
    'a,c,d', 'a', 'a', 'a', 'b,d', 'c,e', 'c', 'a', 'a,d', 'a,d,e',
    'd', NA, 'b,d', 'b,c,d', NA, 'd', 'g', 'b', 'b,d', 'f,g',
    NA, NA, 'a,e', 'b,d,f,g', 'a', NA, 'e', 'a', 'f,g', NA,  
    'b', 'b,d', NA, NA, NA, 'e,f,g', 'a,e', 'g', 'a', 'b,g',
    'g', NA, 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b,c,d,e,g', 'a,d', 
    NA
  ),
  order = FALSE, 
  levels=c('a','b','c','d','e','f','g'), 
  labels=c('PCL retaining','PCL substituting','Ultracongruent (PS Design)','Fixed Bearing', 'Mobile Bearing', 'Increased tibial shaft length','Hinged TKA')
)
#ID comments: NONE

data.frame(Q3_10_3)

##### M Choice Q3.10.3
choicesQ3_10_3 = 
  c('c,g', 'a', 'c,e', 'b', NA, NA, 'a,d', 'a', 'a,e', 'a,d', 
    'a', 'a,b,c,d,e,g', 'a,b,c,d', 'a', 'b', 'a,d', NA, 'a', NA, 'b,d', 
    'a,d', NA, 'g', 'c,e', NA, 'f,g', NA, 'c,e', 'c,d', 'a',
    NA, 'a', 'g', NA, 'a,e', NA, 'b,d', 'a', NA, 'a',
    'a', NA, 'b', 'a,d', 'e', 'a,d', NA, 'a,d', 'c', 'a,d,g',
    'a,c,d', 'a', 'a', 'a', 'b,d', 'c,e', 'c', 'a', 'a,d', 'a,d,e',
    'd', NA, 'b,d', 'b,c,d', NA, 'd', 'g', 'b', 'b,d', 'f,g',
    NA, NA, 'a,e', 'b,d,f,g', 'a', NA, 'e', 'a', 'f,g', NA,  
    'b', 'b,d', NA, NA, NA, 'e,f,g', 'a,e', 'g', 'a', 'b,g',
    'g', NA, 'a', 'a,d', 'a,d', 'a,d', 'a,d','a,b,c,d,e','a,b,c,d,e,g', 'a,d', 
    NA
  )

Q3_10_3_df = multipleChoiceExp(choicesQ3_10_3,"Q3.10.3",lvls)
Q3_10_3_freq = sumFeature(Q3_10_3_df, c("Q3.10.3.a","Q3.10.3.b","Q3.10.3.c","Q3.10.3.d","Q3.10.3.e","Q3.10.3.f","Q3.10.3.g"))

Q3_10_1_vec = as.vector(Q3_10_1_freq)
Q3_10_2_vec = as.vector(Q3_10_2_freq)
Q3_10_3_vec = as.vector(Q3_10_3_freq)

#Q3_10_df = data.frame(c("High Impact","Low Impact", "Kein Sport"),rbind(Q3_10_1_vec, Q3_10_2_vec, Q3_10_3_vec))
#colnames(Q3_10_df) = c("Type","HKB erhaltend","HKB ersetzend", "Ultrakongruent (PS Design)","Fixed Bearing","Mobile Bearing","Tibiale Stielverlängerung","Gekoppelte Prothese (Hinged)")
#print(Q3_10_df)

groupNames = c('PCL\n retaining','PCL\n substituting','ultracongruent\n (PS Design)','bearing\n fixed', 'bearing\n mobile', 'incr. tib.\n shaft length','hinged')
tempLabels = c("Type","Count","TypeSport")

Q3_10_1_df = data.frame(groupNames, Q3_10_1_vec)
Q3_10_1_df['TypeSport'] = "3. High Impact"
colnames(Q3_10_1_df) = tempLabels

Q3_10_2_df = data.frame(groupNames, Q3_10_2_vec)
Q3_10_2_df['TypeSport'] = "2. Low Impact"
colnames(Q3_10_2_df) = tempLabels

Q3_10_3_df = data.frame(groupNames, Q3_10_3_vec)
Q3_10_3_df['TypeSport'] = "1. No Sports"
colnames(Q3_10_3_df) = tempLabels

Q3_10_df = rbind(Q3_10_1_df,Q3_10_2_df,Q3_10_3_df)
Q3_10_df = Q3_10_df[order(Q3_10_df["Type"]),] # ,Q3_10_df["TypeSport"]),]
# df[match(target, df$name),]
# Q3_10_df = df[match(groupNames, Q3_10_df$Type),]

# left_join(data.frame(name=target),df,by="name")
# Q3_10_df = left_join(data.frame(name=groupNames),Q3_10_df,by="name")
row.names(Q3_10_df) <- 1:nrow(Q3_10_df)

# Q3.10 HP: Plotting: Kopplungstyp für eine Knie-TEP
ggp <- ggplot(Q3_10_df,aes(x=Type, y=Count, fill=TypeSport), position="stack", stat='identity') + xlab("") + 
  ylab("Counts") + labs(fill = "Activity Level") + ggtitle("Bearing Type & Surgical Technique") + customPlot
ggp + geom_col() + scale_fill_grey()  + theme(axis.text.x = element_text(angle = 45, hjust = 1, size=12)) + 
  scale_fill_grey(start=0.8, end=0.2) + labs(tag="") + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_10-Histogram.pdf"), width=8, height=5)

################################################################################################################################################################
################################################################################################################################################################

#Q3.11 "Würden Sie bei hohem Sportanspruch zur Anlage von Schmerzkathetern (N. femoralis, N. ischiadicus) raten?"
#"Would you advise to apply pain catheters (N. femoralis, N. sciatic nerve) in patients with high athletic activity expectations?"
# a = "Ja"
#     "Yes"
# b = "Nein"
#     "No"
# c = "Egal"
#     "Does not matter"

Q3_11<- factor(
  c('b', 'c', 'b', 'b', 'c', 'c', 'c', 'b', 'a', 'a', 
    'c', 'c', 'c', 'b', 'b', 'b', 'a', 'b', 'b', 'b', 
    'b', 'c', 'b', 'b', 'b', 'c', 'b', 'a', 'b', 'a',
    'c', 'b', 'b', NA, 'c', 'c', 'b', 'b', NA, 'b',
    'b', 'b', 'c', 'b', 'b', 'c', 'c', 'b', 'b', 'b',
    'b', 'c', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b',
    'c', 'b', 'b', 'b', 'b', 'c', 'c', 'b', 'b', 'b',
    NA, 'b', 'b', 'a', 'b', NA, 'b', 'b', 'b', 'a',  
    'c', 'a', 'c', NA, 'c', 'a', 'b', 'b', 'c', 'b',
    'b', 'a', 'b', 'b', 'b', 'b', 'b', 'b', 'b', 'b',
    'b'
  ),
  order = FALSE, 
  levels=c('a','b','c'), 
  labels=c('yes', 'no', 'no influence')
)
#ID comments: NONE

data.frame(Q3_11)
################################################################################################################################################################
################################################################################################################################################################

#Q3.12 "Hat ein hoher sportlicher Anspruch Einfluss auf die Nachbehandlung (NB)?" 
#"Does a high athletic standard influence post-treatment (NB)?"
# a = "Ja, Nutzung einer CPM (continuous passive motion) Schiene"
#     "Yes, application of a continuous passive motion treatment"
# b = "Ja, forcierte Nachbehandlung"
#     "Yes, enforced rehabilitation"
# c = "Ja, restriktivere Nachbehandlung"
#     "Yes, restrictive rehabilitation"
# d = "Nein"
#     "No"

Q3_12<- factor(
  c('d', 'b', 'd', 'd', 'd', 'c,d', 'd', 'd', 'a,b', 'd', 
    'd', 'd', 'd', 'b', 'd', 'b', 'a', 'd', 'd', 'd', 
    'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd', 'd',
    'b', 'd', 'c', 'a', 'd', 'a,b', 'a,b', 'd', 'b', 'd',
    'd', 'd', 'd', 'a,b', 'd', 'd', 'd', 'd', 'd', 'd',
    'd', 'd', 'd', 'd', 'a', 'd', 'd', 'd', 'b', 'd',
    'a', 'b', 'd', 'b', 'b', 'b', 'd', 'd', 'd', 'd',
    NA, 'd', 'd', 'a', 'd', NA, 'd', 'd', 'a', 'd',  
    'a', 'd', 'd', NA, 'd', 'b', 'a', 'b', 'd', 'a',
    'd', 'a', 'd', 'd', 'd', 'a', 'a','a','d', 'd', 
    'd'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('CPM', 'enforced', 'restrictive', 'no')
)
#ID comments: NONE

data.frame(Q3_12)
################################################################################################################################################################
################################################################################################################################################################

# Q3.13 "Ihr Patient äußert den Wunsch nach der Knie-TEP OP zu zuvor ausgeübten high-impact Sportarten zurückzukehren. Welche Aussage treffen Sie?" 
# "Your patient expresses the wish to return to previously practiced high-impact sports after the knee arthroplasty surgery. Which statement do you make?"
# a = "Ich empfehle es uneingeschränkt nach einer gewissen Schonzeit" 
#     "I recommend it without limitations after a certain time of recovery
# b = "Ich empfehle es nur bei adäquater Schulung des Patienten über die Bewegungen/Risiken."
#     "I recommend it only after adequate training of the patient in regard to movements and risks."
# c = "Ich empfehle keine high-impact Sportarten nach Implantation einer Gelenkendoprothese."
#     "I recommend no high-impact sports after arthroplasty"
# d = "Ich überlasse es dem Patienten und spreche keine konkrete Empfehlung aus."
#     "I leave it to the patient and make no specific statement."

Q3_13<- factor(
  c('b', 'b', 'b', 'c', 'b', 'a', 'c', 'b', 'b', 'c', 
    'b', 'b', 'b', 'b', 'c', 'c', 'b', 'b', 'b', 'c', 
    'c', 'b', 'c', 'b', 'b', 'c', 'b', 'b', 'b', 'b',
    'b', 'c', 'b', 'c', 'c', 'c', 'c', 'b', 'c', 'c',
    'b', 'c', 'b', 'c', 'a', 'b', 'b', 'a', 'b', 'b',
    'b', 'c', 'b', 'c', 'c', 'b', 'b', 'c', 'b', 'c',
    'c', 'b', 'c', 'b', 'b', 'b', 'a', 'b', 'c', 'c',
    NA, 'a', 'b', 'c', 'c', NA, 'a', 'b', 'c', 'c',  
    'c', 'b', 'c', NA, 'c', 'c', 'c', 'b', 'b', 'b',
    'b', 'b', 'd', 'c', 'b', 'b', 'b','b','b', 'b', 
    'b'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('no lim', 'w/ training', 'not rec', "idk")
)
# comments:
#ID_11 "Ich glaube nicht, dass es möglich sein wird" = "I don't know if it will be possible."
#ID_18 "Und weise auf Frakturgefahr, möglicherweise Materialschäden hin" = "I point out the increased risk of periprosthetic fracture, potential material breaches."

data.frame(Q3_13)

################################################################################################################################################################
################################################################################################################################################################

#Q3.14 "Wie lautet Ihre Sport Empfehlung nach Implantation einer Knie-Totalendoprothese (Knie-TEP)?"
# "What is your recommendation for sports after a total knee arthroplasty (TKA)?"
# a = "n. 3 Monaten"
#     "after 3 months"
# b = "n. 6 Monaten"
#     "after 6 months"
# c = "nicht empfohlen"
#     "not recommended"
# d = "unentschieden"
#     "undecided"

lvls =  c("a","b","c","d")

# Q3.14.1 High-Impact 
Q3_14_1<- factor(
  c('b', 'b', 'b', 'c', 'a', 'b', 'c', 'a', 'c', 'c', 
    'b', 'b', 'c', 'b', 'c', 'c', 'c', 'b', 'b', 'c', 
    'c', 'd', 'c', 'b', 'b', 'c', 'b', 'b', 'a', 'b',
    'b', 'b', NA, 'c', 'c', 'c', 'b', 'b', NA, 'c',
    'b', 'c', 'c', 'c', 'b', 'b', 'b', 'b', 'b', 'b',
    'b', NA, 'b', 'c', 'c', 'b', 'c', 'c', 'b', 'c',
    'c', 'b', 'c', 'b', 'b', 'b', 'b', 'b', 'c', 'c',
    NA, 'a', 'b', 'c', 'c', NA, 'b', 'b', 'a', 'c',  
    'c', 'b', 'c', NA, 'c', 'c', 'c', 'b', 'b', 'b',
    'b', 'd', 'd', 'b', 'b', 'b', 'b','b','b', 'b', 
    'b'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('>3 M','>6 M','Not recommended','Undecided')
)
#ID comments: NONE.

data.frame(Q3_14_1)

##### M Choice Q3.14.1
choicesQ3_14_1 = 
  c('b', 'b', 'b', 'c', 'a', 'b', 'c', 'a', 'c', 'c', 
    'b', 'b', 'c', 'b', 'c', 'c', 'c', 'b', 'b', 'c', 
    'c', 'd', 'c', 'b', 'b', 'c', 'b', 'b', 'a', 'b',
    'b', 'b', NA, 'c', 'c', 'c', 'b', 'b', NA, 'c',
    'b', 'c', 'c', 'c', 'b', 'b', 'b', 'b', 'b', 'b',
    'b', NA, 'b', 'c', 'c', 'b', 'c', 'c', 'b', 'c',
    'c', 'b', 'c', 'b', 'b', 'b', 'b', 'b', 'c', 'c',
    NA, 'a', 'b', 'c', 'c', NA, 'b', 'b', 'a', 'c',  
    'c', 'b', 'c', NA, 'c', 'c', 'c', 'b', 'b', 'b',
    'b', 'd', 'd', 'b', 'b', 'b', 'b','b','b', 'b', 
    'b'
  )

Q3_14_1_df = multipleChoiceExp(choicesQ3_14_1,"Q3.14.1",lvls)
Q3_14_1_freq = sumFeature(Q3_14_1_df, c("Q3.14.1.a","Q3.14.1.b","Q3.14.1.c","Q3.14.1.d"))

# Q3.14.2 Low-Impact 
Q3_14_2<- factor(
  c('a', 'a', 'a', 'a', 'a', 'b', 'b', 'a', 'b', 'a', 
    'a', 'a', 'b', 'a', 'a', 'b', 'a', 'a', 'a', 'a', 
    'a', 'a', 'a', 'a', 'a', 'b', 'a', 'a', 'a', 'a',
    'b', 'b', 'b', 'b', 'a', 'b', 'b', 'a', NA, 'b',
    'a', 'a', 'a', 'b', 'a', 'a', 'a', 'a', 'a', 'a',
    'a', NA, 'a', 'a', 'a', 'a', 'b', 'a', 'a', 'a',
    'b', 'b', 'b', 'b', 'b', 'a', 'a', 'a', 'b', 'b',
    NA, 'a', 'b', 'b', 'b', NA, 'a', 'a', 'a', 'a',  
    'a', 'b', 'a', NA, 'a', 'b', 'a', 'a', 'b', 'a',
    'a', 'd', 'a', 'a', 'a', 'a', 'a','b','a', 'a', 
    'a'
  ),
  order = FALSE, 
  levels=c('a','b','c','d'), 
  labels=c('>3 M','>6 M','Not recommended','Undecided')
)
#ID comments: NONE

data.frame(Q3_14_2)

##### M Choice Q3.14.2
choicesQ3_14_2 = 
  c('a', 'a', 'a', 'a', 'a', 'b', 'b', 'a', 'b', 'a', 
    'a', 'a', 'b', 'a', 'a', 'b', 'a', 'a', 'a', 'a', 
    'a', 'a', 'a', 'a', 'a', 'b', 'a', 'a', 'a', 'a',
    'b', 'b', 'b', 'b', 'a', 'b', 'b', 'a', NA, 'b',
    'a', 'a', 'a', 'b', 'a', 'a', 'a', 'a', 'a', 'a',
    'a', NA, 'a', 'a', 'a', 'a', 'b', 'a', 'a', 'a',
    'b', 'b', 'b', 'b', 'b', 'a', 'a', 'a', 'b', 'b',
    NA, 'a', 'b', 'b', 'b', NA, 'a', 'a', 'a', 'a',  
    'a', 'b', 'a', NA, 'a', 'b', 'a', 'a', 'b', 'a',
    'a', 'd', 'a', 'a', 'a', 'a', 'a','b','a', 'a', 
    'a'
  )

Q3_14_2_df = multipleChoiceExp(choicesQ3_14_2,"Q3.14.2",lvls)
Q3_14_2_freq = sumFeature(Q3_14_2_df, c("Q3.14.2.a","Q3.14.2.b","Q3.14.2.c","Q3.14.2.d"))

#String the vectors together
Q3_14_1_vec = as.vector(Q3_14_1_freq)
Q3_14_2_vec = as.vector(Q3_14_2_freq)

groupNames = c(">3 M",">6 M","not rec", "undec")
tempLabels = c("Type","Count","TypeSport")
Q3_14_1_df = data.frame(groupNames, Q3_14_1_vec)
Q3_14_1_df['TypeSport'] = "2. High Impact"
colnames(Q3_14_1_df) = tempLabels

Q3_14_2_df = data.frame(groupNames, Q3_14_2_vec)
Q3_14_2_df['TypeSport'] = "1. Low Impact"
colnames(Q3_14_2_df) = tempLabels

Q3_14_df = rbind(Q3_14_1_df,Q3_14_2_df)
Q3_14_df = Q3_14_df[order(Q3_14_df["Type"]),] # ,Q3_14_df["TypeSport"]),]
row.names(Q3_14_df) <- 1:nrow(Q3_14_df)

# Q3.14 HP: Empfehlung Zeit nach Knie-TEP
ggp <- ggplot(Q3_14_df,aes(x=Type, y=Count, fill=TypeSport), position="stack", stat='identity') + xlab("") + 
  ylab("Counts") + labs(fill = "Activity Level") + ggtitle("Time to RTS after TKA") + customPlot + labs(tag="B") + coord_flip() + theme(legend.position = "bottom") + theme(
    panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                    size = 2, linetype = "solid"),
    panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                    colour = "grey75"), 
    panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                    colour = "grey75")
  )
ggp + geom_col() + scale_fill_grey(start = 0.8, end=0.2) + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100))
ggsave(paste(path, "Q3_14-Histogram.pdf"), width=5, height=4) 
################################################################################################################################################################
################################################################################################################################################################
################################################################################################################################################################
################################################################################################################################################################

##### Multiple Choice Table Q4 listing 30 different sport types and 4 different levels of recommendation for patients after THA #####
# This question was designed as a table containing 30 different sporting activities listed and four different recommendations for patients after THA
# 4.1 = without limitations
# 4.2 = with adequate training
# 4.3 = not recommended
# 4.4 = undecided

#Q4 "Wie lautet Ihre Empfehlung für Patienten nach Hüft-Total-Endoprothesenersatz?"
# "What is your recommendation for patients after total hip replacement?"
# a = "Basketball" = "Basketball"
# b = "Bowling" = "Bowling"
# c = "Boxing/Kampfsport" = "Boxing/Martial Arts"
# d = "E-Scooter fahren" = "E-Scooter"
# e = "Fitness/Gewichte heben" = "Fitness/Weights"
# f = "Fußball" = "Soccer"
# g = "Gesellschaftstanz (Partner)" = "Ballroom Dancing"
# h = "Golf" = "Golf"
# i = "Handball" = "Handball"
# j = "Hockey" = "Hockey"
# k = "Joggen" = "Jogging"
# l = "Klettern" = "Climbing"
# m = "Pilates" = "Pilates"
# n = "Radfahren Ebene" = "Biking level"
# o = "Radfahren Unebene" = "Biking cross"
# p = "Reiten" = "Horseback riding"
# q = "Rudern" = "Rowing"
# r = "Schwimmen" = "Swimming"
# s = "Skifahren (alpin)" = "Ski slope"
# t = "Skilanglauf" = "Ski long"
# u = "Spazieren" = "Walking"
# v = "Squash" = "Squash"
# w = "Surfen" = "Surfing"
# x = "Tanzen" = Dancing"
# y = "Tennis" = "Tennis"
# z = "Tischtennis" = "Table tennis"
# 1 = "Turnen" = "Gymnastics"
# 2 = "Volleyball" = "Volleyball"
# 3 = "Wandern" = "Hiking"
# 4 = "Yoga" = "Yoga"

lvls = c("a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","1","2","3","4")

##### M Choice Q4.1 : type of sports recommended "without limitations" after THA
choicesQ4_1 = 
  c('b,d,e,g,h,k,m,n,o,p,q,r,t,u,x,3,4', NA, 'b,c,d,e,g,h,j,m,,n,o,w,r,t,u,x,y,z,3', 'n,o,r,t,u,x,3,4', 'b,d,e,g,h,k,m,n,o,r,s,t,u,w,x,y,z,3', 'b,d,e,g,h,i,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,2,3', 'r,u,3', NA, 'd,g,k,n,q,r,u,x,3', 'n,u', 
    'e,g,m,n,o,p,q,r,s,t,u,x,y,z,3,4', 'g,m,n,o,p,q,r,t,u,x,z,3,4', 'n,r,u,x,3', 'b,d,e,g,h,k,m,n,o,p,q,r,t,u,x,y,z,3,4', 'b,g,h,k,m,n,o,p,r,t,u,x,3,4', 'b,g,h,m,n,o,q,r,t,u,x,z,3,4', 'n,o,u,3', 'd,g,u,3', 'b,d,e,g,h,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,3,4', 'a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,2,3', 
    'b,d,g,h,m,n,o,p,q,r,t,u,x,3,4', 'b,d,h,n,q,r,t,u,w,3', 'g,h,r,u,3', 'b,h,n,o,r,u', 'd,f,g,k,m,n,o,p,q,r,s,t,u,w,x,3', 'n,u', 'e,k,n,q,r,u', 'h,k,n,o,s,u,x,y,z,3', 'a,b,d,e,g,h,k,m,n,o,p,q,r,t,u,v,w,x,y,z,1,2,3', NA,
    'd,e,g,h,m,n,o,p,q,r,s,t,u,z,3', 'b,d,e,g,h,n,o,r,u,x,3', 'd,e,g,k,n,o,r,t,u,x,z,3', 'n,r,u,x,3', NA, 'b,d,e,g,h,m,n,o,p,q,r,t,u,x,z,3', 'g,h,m,n,o,p,w,r,u,x,y,z,3,4', 'h,k,n,o,q,u,x,3', 'n,o,r,t,u,x,3', 'e,m,n,t,u,3',
    'a,b,c,d,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,,w,x,y,z,1,2,3', 'b,d,g,h,k,m,n,o,q,r,u,x,2', 'b,d,e,k,m,n,o,q,r,t,u,w,x,y,z,3', 'b,g,h,m,n,r,t,u,x,3,4', 'a,b,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,4',NA, 'd,e,g,h,m,n,o,q,r,t,u,x,2,3,4', 'b,d,e,g,h,k,l,m,n,o,p,q,r,s,t,u,w,x,3,4', 'd,e,g,h,m,n,o,q,r,s,t,u,w,y,z,3', 'b,d,g,h,k,m,n,o,p,q,r,t,u,w,x,3,4',
    'n,r,u,x,3', 'n,3', 'b,g,h,k,l,m,n,o,p,q,r,u,w,x,3', 'a,b,d,e,g,h,i,j,k,l,m,n,o,r,s,t,u,w,x,y,z,3,4', 'b,g,h,j,k,n,o,p,q,r,t,u,v,w,x,z,1,3', NA, 'b,d,g,h,n,o,r,t,u,3,4', 'b,g,h,k,n,o,q,r,u,x,z,3,4', 'd,e,m,n,p,q,r,t,u,x,z,3', 'b,m,n,r,u,3',
    'b,m,n,q,t,u,x,3,4', 'd,e,n,o,q,r,t,u,x,3', 'b,g,h,m,n,o,r,u,x,3', 'a,g,k,m,n,t,u,3,4', 'g,m,n,t,u,x,3,4', 'b,g,h,k,n,p,t,u,x,z,3', 'b,d,f,g,h,i,j,n,o,p,r,s,t,u,x,y,z,2,3', 'd,g,h,l,m,n,r,t,u,x,3,4', 'g,u,x,3', 'g,n,o,q,r,s,t,u,x,3',
    NA, 'c,d,e,g,h,k,n,o,p,q,r,t,u,x,y,z,3,4', 'n,o,r,t,u,3,4', 'b,n,o,q,r,u', NA, 'a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4', 'g,n,r,t,u,x,3,4', 'n,u,3', 'h,m,n,o,p,t,u,3,4',  
    'g,m,n,o,q,r,u,x,3', 'b,d,g,k,l,m,n,o,p,q,r,t,u,w,x,z,3', 'd,e,g,h,k,n,o,p,q,r,t,u,w,x,3', 'k,n,r', 'b,d,e,g,h,n,o,p,q,r,t,u,x,3', 'g,n,q,r,t,u,x,3', 'b,d,g,h,k,n,o,r,t,u,x,y,z,3', 'b,e,f,g,h,k,l,m,o,p,q,r,u,w,y,z,1,3,4', 'b,d,e,g,h,k,n,o,p,r,t,u,x,z,3', 'b,d,e,h,k,n,o,p,r,t,u,z,3',
    'd,g,h,k,m,n,o,p,r,t,u,x,3', 'u,3', 'g,h,m,n,o,q,r,t,u,x,3,4', 'd,g,h,n,o,q,r,t,u,x,z,3', 'g,h,n,r,u,3', 'g,k,n,r,t,u', 'd,e,g,h,n,o,u,x,z,3','g,h,n,q,r,u,z,2,3','n,u,z,3'
  )

Q4_1_df = multipleChoiceExp(choicesQ4_1,"Q4_1",lvls)
Q4_1_freq = sumFeature(Q4_1_df, 
                       c("Q4_1.a","Q4_1.b","Q4_1.c","Q4_1.d","Q4_1.e","Q4_1.f","Q4_1.g","Q4_1.h","Q4_1.i","Q4_1.j",
                         "Q4_1.k","Q4_1.l","Q4_1.m","Q4_1.n","Q4_1.o","Q4_1.p","Q4_1.q","Q4_1.r","Q4_1.s","Q4_1.t",
                         "Q4_1.u","Q4_1.v","Q4_1.w","Q4_1.x","Q4_1.y","Q4_1.z","Q4_1.1","Q4_1.2","Q4_1.3","Q4_1.4"))

##### M Choice Q4.2 : type of sports recommended "with adequate training"
choicesQ4_2 = 
  c('a,f,j,l,s,w,y,z,2', 'b,d,e,g,h,k,l,m,n,o,p,q,r,s,t,u,x,y,z,3,4', 'a,f,i,k,l,,p,c,v,w,1,2,4', 'd,g,h,p,q', 'a,f,i,j,p,v,2,4', 'a,c,f,j,4', 'b,e,g,h,m,n,p,q,t,x,z,1,4', 'a,e,h,k,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3', 'b,e,h,l,o,p,s,t,y,z,2', 'a,b,d,e,g,h,j,k,l,m,n,o,p,q,r,t,v,w,x,y,z,2,3,4', 
    'a,c,h,j,w,1', 'a,b,c,d,e,f,h,i,j,k,l,s,v,w,y,1,2', 'b,d,e,g,h,k,l,m,o,p,q,t,w,y,z,1,4', 'a,c,f,i,j,l,s,v,w,2', 'd,e,j,l,q,s,v,y,z,1', 'e,p', 'b,d,e,g,h,m,q,r,t,w,x,z,1,4', 'a,b,c,e,f,h,i,j,m,n,o,p,q,r,s,t,v,w,x,y,z,1', 'a,c,f,i,j,1,2', '1', 
    'e,f,k,s,y,z,1,2', 'c,e,g,k,l,m,o,p,s,v,x,y,z,1,4', 'a,b,d,e,k,m,n,o,t,w,x,y,z,4', 'd,e,g,j,k,l,m,n,p,q,s,t,w,x,y,z,1,2,3,4', 'a,e,h,i,j,y,z,1,2', 'b,e,g,h,k,m,o,q,r,x,y,z,1,3,4', 'a,b,c,d,g,h,m,o,p,t,v,w,x,y,z,1,2,3,4', 'a,b,e,g,i,l,m,p,q,r,t,1,2,4', 'f,i,j,l,4', NA,
    'a,b,c,f,j,k,l,w,x,y,1,2,4', 'k,l,m,p,t,w,y,z,4', 'a,c,f,h,i,j,m,p,w,s,v,w,y,1,2,4', 'g,h,k,m,o,p,s,t,y,z,4', NA, 'a,c,i,l,s,w,y,1,2,4', 'b,d,j,l,s,t,w,1', 'b,d,e,g,l,m,p,l,s,t,v,w,y,z,1,4', 'b,d,e,g,h,k,l,m,p,q,z,1,2,4', 'b,d,e,g,h,k,o,q,r,s,x,y,z,2,4',
    'e,4', 'e,y,z,4', 'h,j,l,p,s,v,2,4', 'd,e,o,p,q,s,z,1', 'c', NA, 'a,b,c,e,f,i,j,k,l,p,s,w,y,z,1', 'a,c,f,i,j,v,y,z,1,2', 'b,i,j,k,l,p,x,1,2,4', 'a,c,e,f,i,j,l,s,v,y,z,1,2',
    'a,b,c,d,e,f,g,h,i,j,k,l,m,,o,p,q,s,t,v,w,y,z,1,2,4', 'b,d,e,g,h,m,o,r,s,t,u,x,y,z,4', 'a,e,f,i,j,s,t,v,y,z,1,2,4', 'q', 'c,d,f,l,s,4', 'b,c,d,e,f,g,h,l,m,n,o,p,q,r,s,t,u,v,x,y,z,1,3,4', 'a,e,k,m,p,q,s,x,z,1', 'd,j,l,m,p,s,t,v,w,y', 'a,b,c,f,h,i,j,k,l,o,s,v,w,y,1,2,4', 'a,e,g,h,k,o,p,q,s,t,w,x,y,z,2,4',
    NA, 'a,b,g,h,k,m,p,s,y,z,1,4', 'd,e,l,q,s,t,w,y,z,1,4', 'a,b,d,e,f,h,i,j,o,p,q,r,s,v,w,x,y,z,1,2', 'a,b,d,e,f,h,i,j,k,o,p,q,r,s,v,w,y,z,1,2', 'a,e,f,i,j,l,m,o,q,r,s,v,w,y,1,2,4', 'c,e,k,l,q,w,1,4', 'a,b,c,e,f,i,j,k,o,p,q,s,w,y,z,1,2', 'b,e,h,m,n,r,t,y,1,4', 'b,d,e,h,k,m,p,y,z,1,2',
    NA, 'a,b,m', 'b,e,g,h,k,m,q,s,x,y,z', 'e,f,g,h,i,j,k,m,p,s,t,v,w,x,y,z,1,2,3,4', NA, 'b,d,e,g,h,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4', 'e,h,k,m,o,p,q,s,1', 'c,d,g,h,m,o,r,t,x,z,4', 'a,b,d,e,f,g,i,j,k,l,q,r,v,w,y,z,1,2',  
    'b,d,e,l,p,s,t,w,y,z', 'a,c,e,f,h,s,v,y,1,2,4', 'b,c,m,s,y,z,1,4', 'o,p', 'm', 'b,e,h,k,m,p,4', 'e,l,m,p,q,s,t,w,2,4', 'a,i,j,s,t,2', 'a,c,f,i,j,l,m,q,s,v,w,y,1,2,4', 'c,g,l,m,q,s,w,x,y,1,2,4',
    'b,e,l,p,q,s,y,z,1,4', 'a,b,e,f,g,h,i,k,l,m,n,o,q,r,t,v,x,y,z,2,4', 'a,b,d,e,k,l,p,s,w,y,z,2', 'b,e,k,l,m,p,s,w,1,2,4', 'b,d,e,k,l,m,o,p,w,s,t,w,x,1,2,4', 'a,b,e,f,h,l,m,p,q,s,w,x,y,z,1,2,3,4', 'a,b,c,f,i,j,k,l,m,q,r,s,t,v,y,2,4','a,b,c,d,e,f,i,j,k,l,m,o,p,s,t,v,w,x,y,1,4','a,b,c,d,e,f,g,h,i,j,k,l,m,o,p,q,r,s,t,v,w,x,y,1,2,4'
  )

Q4_2_df = multipleChoiceExp(choicesQ4_2,"Q4_2",lvls)
Q4_2_freq = sumFeature(Q4_2_df, 
                       c("Q4_2.a","Q4_2.b","Q4_2.c","Q4_2.d","Q4_2.e","Q4_2.f","Q4_2.g","Q4_2.h","Q4_2.i","Q4_2.j",
                         "Q4_2.k","Q4_2.l","Q4_2.m","Q4_2.n","Q4_2.o","Q4_2.p","Q4_2.q","Q4_2.r","Q4_2.s","Q4_2.t",
                         "Q4_2.u","Q4_2.v","Q4_2.w","Q4_2.x","Q4_2.y","Q4_2.z","Q4_2.1","Q4_2.2","Q4_2.3","Q4_2.4"
                       ))

##### M Choice Q4.3 : type of sports not recommended
choicesQ4_3 = 
  c('c,i,v,1', 'a,c,f,i,j,v,w,1,2', NA, 'a,c,e,f,i,j,k,l,s,v,w,y,z,1,2', 'c,l,1', '1', 'a,c,f,i,j,k,l,o,s,v,w,y,2', 'c,f,i,l,4', 'a,c,f,i,j,m,v,w,1,4', 'c,f,i,s,1', 
    'd,f,i,k,l,v', NA, 'a,c,f,i,j,s,v,2', '1', 'a,c,f,i,v,2', 'a,c,d,f,i,j,k,l,s,v,w,y,1,2', 'a,c,f,i,j,k,l,p,s,v,y,2', 'k,l', NA, '4', 
    'a,c,i,j,v,w', 'a,f,i,j,2', 'c,f,i,j,l,p,q,s,v,1,2', 'a,c,f,i,v', 'c,l', 'a,c,d,f,i,j,c,p,s,t,v,w,2', 'f,i,j,l,s', 'c,d,f,j,v,w', 'c,s', NA,
    'i,v', 'a,c,f,i,j,w,s,v,1,2', 'b,l', 'a,c,d,e,f,i,j,l,w,v,w,1,2', 'c,d,f,i', 'f,k,v', 'a,c,f,i,k,v,2', 'a,c,f,i,j,2', 'a,c,f,i,j,s,v,w,y', 'a,c,f,i,j,l,p,v,w,1',
    NA, 'a,c,f,i,j,l,p,s,t,v,w,1,2', 'a,i,1', 'a,c,f,i,j,k,l,v,w,y,2', NA, NA, 'v', NA, 'a,c,f', NA,
    NA, 'a,c,f,i,j,k,l,p,q,v,w,1,2', 'c,f,i', 'c,f,p,q,v,1,2', 'a,e,i,y,2', 'a,i,j,l,w,2', 'c,f,i,j,l,v,w,y,2', 'a,c,e,f,i,1,2', NA, 'c,f,i,j,l,v,1',
    'a,c,e,f,h,i,j,k,l,s,v,w,y,z,1,2', 'c,f,i,l,v,2', 'a,c,f,i,j,k,p,v,2', 'c,l', 'c,l', 'c', 'a,v', 'v', 'a,c,d,f,i,j,k,l,o,p,q,s,v,z,2', 'a,c,f,i,j,l,v,4',
    NA, 'f,i,j,l,s,v,w,1,2', 'a,c,d,f,i,j,l,p,v,w,1,2', 'a,c,d,l', NA, NA, 'a,b,c,d,f,i,j,l,v,w,y,z', 'a,b,e,f,i,j,k,l,p,q,s,v,w,y,1,2', 'c,s',  
    'a,c,f,h,i,j,k,v,1,2,4', 'i,j', 'a,f,i,j,l,v,2', NA, 'a,c,f,i,j,k,l,v,w,1,2', 'a,c,f,i,j,l,o,s,v,w,y,z,1,2', 'a,c,f,i,j,v,1', 'c,d,v', NA, 'a,f,i,j,v',
    'a,c,i,j', 'c,j,p,s,w,1', 'c,f,i,j,v,1', 'a,c,f,i,j,v,y', 'a,c,f,i,j,v,y,z', 'c,d,i,j,o,v', 'p,w,1', NA, NA
  )

Q4_3_df = multipleChoiceExp(choicesQ4_3,"Q4_3",lvls)
Q4_3_freq = sumFeature(Q4_3_df, 
                       c("Q4_3.a","Q4_3.b","Q4_3.c","Q4_3.d","Q4_3.e","Q4_3.f","Q4_3.g","Q4_3.h","Q4_3.i","Q4_3.j",
                         "Q4_3.k","Q4_3.l","Q4_3.m","Q4_3.n","Q4_3.o","Q4_3.p","Q4_3.q","Q4_3.r","Q4_3.s","Q4_3.t",
                         "Q4_3.u","Q4_3.v","Q4_3.w","Q4_3.x","Q4_3.y","Q4_3.z","Q4_3.1","Q4_3.2","Q4_3.3","Q4_3.4"
                       ))

##### M Choice Q4.4 : type of sports "undecided" recommendation
choicesQ4_4 = 
  c(NA, NA, NA, 'b,m', NA, NA, 'd', NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA, 'NA', 'v,4', NA, NA, NA, NA, NA,
    NA, NA, NA, NA, NA, 'j', NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
    'd,g,o,p,r', 'w', NA, NA, NA, 'd', NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,  
    NA, NA, NA, NA, 's,y,z,4', 'd', NA, NA, NA, NA,
    'f,v,w,z', 'd', NA, NA, NA, NA, NA, NA, NA
  )

Q4_4_df = multipleChoiceExp(choicesQ4_4,"Q4_4",lvls)
Q4_4_freq = sumFeature(Q4_4_df, 
                       c("Q4_4.a","Q4_4.b","Q4_4.c","Q4_4.d","Q4_4.e","Q4_4.f","Q4_4.g","Q4_4.h","Q4_4.i","Q4_4.j",
                         "Q4_4.k","Q4_4.l","Q4_4.m","Q4_4.n","Q4_4.o","Q4_4.p","Q4_4.q","Q4_4.r","Q4_4.s","Q4_4.t",
                         "Q4_4.u","Q4_4.v","Q4_4.w","Q4_4.x","Q4_4.y","Q4_4.z","Q4_4.1","Q4_4.2","Q4_4.3","Q4_4.4"
                       ))

# extract the pure numerical values
Q4_1_vec = as.vector(Q4_1_freq)
Q4_2_vec = as.vector(Q4_2_freq)
Q4_3_vec = as.vector(Q4_3_freq)
Q4_4_vec = as.vector(Q4_4_freq)

groupNames = c("Basketball","Bowling","Boxing","E-Scooter","Fitness/Weights",
               "Soccer","Ballroom","Golf","Handball","Hockey","Jogging",
               "Climbing","Pilates","Biking level","Biking cross","Horseback",
               "Rowing","Swimming","Ski slope","Ski long","Walking",
               "Squash","Surfing","Dancing","Tennis","Table tennis","Gymnastics","Volleyball",
               "Hiking","Yoga")
tempLabels = c("Type","Count","Recommendation")

Q4_1_df = data.frame(groupNames, Q4_1_vec)
Q4_1_df['Recommendation'] = "4. Without limitations"
colnames(Q4_1_df) = tempLabels

Q4_2_df = data.frame(groupNames, Q4_2_vec)
Q4_2_df['Recommendation'] = "3. With training"
colnames(Q4_2_df) = tempLabels

Q4_3_df = data.frame(groupNames, Q4_3_vec)
Q4_3_df['Recommendation'] = "2. Not recommended"
colnames(Q4_3_df) = tempLabels

Q4_4_df = data.frame(groupNames, Q4_4_vec)
Q4_4_df['Recommendation'] = "1. Undecided"
colnames(Q4_4_df) = tempLabels

Q4_df = rbind(Q4_1_df,Q4_2_df,Q4_3_df,Q4_4_df)
Q4_df = Q4_df[order(Q4_df["Type"]),]
row.names(Q4_df) <- 1:nrow(Q4_df)


# Q4 HP: Sport Empfehlung nach Hüft-TEP
ggp <- ggplot(Q4_df,aes(x=Type, y=Count, fill=Recommendation), position="stack", stat='identity') + xlab(" ") + 
  ylab("Counts") + labs(fill = "Recommendation") + ggtitle("Activity recommendations after THA") + customPlot
ggp + geom_col() + scale_fill_manual(values=grey.colors(4, start = 0.8, end=0.2)) + 
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size=12)) + scale_y_continuous(limits = c(0,100)) + labs(tag="") + theme(
    panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                    size = 2, linetype = "solid"),
    panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                    colour = "grey75"), 
    panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                    colour = "grey75")
  )
ggsave(paste(path, "Q4-Histogram.pdf"), width=10, height=5)
################################################################################################################################################################
################################################################################################################################################################

##### Multiple Choice Table Q5 listing 30 different sport types and 4 different levels of recommendation for patients after TKA #####
# This question was designed as a table containing 30 different sporting activities listed and four different recommendations for patients after TKA
# 4.1 = without limitations
# 4.2 = with adequate training
# 4.3 = not recommended
# 4.4 = undecided

#Q5 "Wie lautet Ihre Empfehlung für Patienten nach Knie-Total-Endoprothesenersatz?
# "What is your recommendation for patients after total knee replacement?"
# a = "Basketball" = "Basketball"
# b = "Bowling" = "Bowling"
# c = "Boxing/Kampfsport" = "Boxing/Martial Arts"
# d = "E-Scooter fahren" = "E-Scooter"
# e = "Fitness/Gewichte heben" = "Fitness/Weights"
# f = "Fußball" = "Soccer"
# g = "Gesellschaftstanz (Partner)" = "Ballroom Dancing"
# h = "Golf" = "Golf"
# i = "Handball" = "Handball"
# j = "Hockey" = "Hockey"
# k = "Joggen" = "Jogging"
# l = "Klettern" = "Climbing"
# m = "Pilates" = "Pilates"
# n = "Radfahren Ebene" = "Biking level"
# o = "Radfahren Unebene" = "Biking cross"
# p = "Reiten" = "Horseback riding"
# q = "Rudern" = "Rowing"
# r = "Schwimmen" = "Swimming"
# s = "Skifahren (alpin)" = "Ski slope"
# t = "Skilanglauf" = "Ski long"
# u = "Spazieren" = "Walking"
# v = "Squash" = "Squash"
# w = "Surfen" = "Surfing"
# x = "Tanzen" = Dancing"
# y = "Tennis" = "Tennis"
# z = "Tischtennis" = "Table tennis"
# 1 = "Turnen" = "Gymnastics"
# 2 = "Volleyball" = "Volleyball"
# 3 = "Wandern" = "Hiking"
# 4 = "Yoga" = "Yoga"

##### Multiple Choice Q5.1 : Type of sports recommendation level "without limitations" after TKA
lvls = c("a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","1","2","3","4")
choicesQ5_1 = 
  c('b,d,e,g,h,k,m,n,o,p,q,r,s,t,u,x,y,', NA, 'b,d,g,h,j,n,o,p,r,t,u,x,z,1,3,4', 'm,n,o,p,q,r,t,u,x,3,4', 'b,d,e,g,h,k,m,n,o,q,r,s,t,u,x,z,3,4', 'a,b,d,e,g,h,i,j,l,m,n,o,p,q,r,t,u,v,w,x,y,z,,1,2,3,4', 'g,m,q,r,u,3', NA, 'd,e,g,n,q,r,t,u,x,3', 'b,d,g,h,m,n,q,t,u,x,3', 
    NA, 'a,b,d,e,f,g,h,i,j,l,m,n,o,p,q,r,t,u,w,x,z,3,4', 'b,g,h,m,n,r,t,u,x,3', 'b,d,e,g,h,k,m,n,o,p,q,r,t,u,x,y,z,3,4', 'b,g,h,k,m,n,o,p,r,t,u,x,3,4', 'b,g,m,n,o,q,r,t,u,x,z,3,4', 'b,g,h,m,n,o,r,u,x,3,4', 'b,d,g,n,u,3', 'b,d,e,g,h,k,l,m,n,o,p,q,r,t,u,x,3,4', 'a,b,d,e,f,g,h,i,j,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4', 
    'b,d,e,g,h,l,m,n,o,p,q,r,t,u,x,3,4', 'b,d,h,q,r,t,u', 'g,h,k,n,o,p,q,r,u,x,3', 'b,h,n,o,r,t,u', 'b,d,e,f,g,h,k,m,n,o,p,q,r,s,t,u,w,x,y,z,1,2,3,4', 'u', 'e,k,n,o,q,r,u,3,4', 'b,e,h,k,l,n,o,p,q,r,s,t,u,x,y,z,3,4', 'b,g,h,k,m,n,o,p,q,r,t,u,w,x,y,z,1,2,3', NA,
    'de,g,h,k,m,n,o,p,q,r,s,t,u,x,z,3,4', NA, 'd,e,g,h,k,m,n,o,p,q,r,t,u,x,z,3', 'n,r,u,x,3', NA, 'b,d,e,g,h,m,n,o,p,q,r,t,u,x,3,4', 'b,e,g,h,m,n,o,p,q,r,u,w,x,3,4', 'h,k,m,n,o,q,r,t,u,x,3,4', 'd,g,n,o,p,r,t,u,x,3', 'e,m,n,r,t,u,3,4',
    NA, 'b,d,g,h,k,m,n,o,q,r,u,x,3,4', 'd,e,g,h,k,l,m,n,o,p,r,t,u,x', 'b,g,h,m,n,r,t,u,x,3,4', 'a,b,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4', NA, 'd,e,g,h,k,m,n,o,p,q,r,u,3,4', 'b,d,e,g,h,k,l,n,m,o,p,q,r,s,t,u,w,x,z,1,3,4', 'd,e,g,h,m,n,o,q,r,s,t,u,w,y,z,1,3', 'b,d,e,g,h,k,m,n,o,p,q,r,t,u,w,x,3,4',
    'n,r,u,x,3', 'h,n,o,r,t,u,3', 'b,d,g,h,k,l,m,n,o,p,q,r,u,x,3,4', 'a,b,d,e,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,w,x,y,z,1,2,3,4', 'b,g,h,k,n,o,q,r,t,u,w,x,z,3,4', NA, 'b,d,e,g,h,m,n,o,r,t,u,x,z,3,4', 'b,d,g,h,k,n,o,q,r,t,u,x,3,4', 'b,d,g,h,m,n,p,q,r,t,u,x,y,z,3', 'b,m,n,u,3',
    'b,d,g,m,n,o,p,q,r,t,u,x,3,4', 'b,d,e,g,h,n,o,p,q,r,t,u,w,x', 'b,g,h,m,n,o,r,u,x,3,4', 'g,k,m,n,t,u,x,3,4', 'g,h,m,n,r,t,u,3,4', 'b,g,h,k,n,p,q,r,t,u,x,z,3,4', 'b,d,f,g,h,i,j,n,o,p,r,s,t,u,x,y,z,2,3', 'b,d,g,h,l,m,n,q,r,t,u,w,x,z,3,4', 'g,h,n,t,u,x,3', 'd,g,h,n,o,q,r,s,t,u,x,y,z,3,4',
    NA, 'b,c,d,e,g,h,m,n,o,p,q,r,t,u,x,y,z,1,3,4', 'k,m,n,o,r,t,u,3,4', 'h,k,m,n,t,u,x,3,4', 'b,e,h,k,m,n,o,p,q,r,u', NA, 'a,c,i,j,k,v', 'g,m,n,r,t,u,x', 'n,r,u,3,4', 'h,m,n,o,p,r,t,u,3,4',  
    'g,m,n,o,q,r,u,x,3', 'b,d,g,k,l,m,n,o,p,q,r,t,u,w,x,z,3,4', 'd,e,g,h,n,o,p,q,r,t,u,x,3,4', NA, 'b,d,e,g,h,m,n,o,p,q,r,t,u,x,3,4', 'g,h,n,r,t,u,x,3', 'b,d,g,h,k,n,o,r,t,u,x,3,4', 'b,e,g,h,k,l,m,n,o,p,q,r,u,v,w,x,z,3,4', 'b,d,e,g,h,k,m,n,o,p,r,t,u,x,z,3,4', 'b,d,e,g,h,k,m,n,o,p,r,t,u,x,z,3,4',
    'b,d,g,h,k,n,o,r,u,x,3', 'b,d,g,h,n,q,r,u,x,3', 'g,h,m,n,o,q,r,t,u,x,3,4', 'b,d,e,g,h,l,m,n,o,p,q,r,s,t,u,w,x,z,1,2,3,4', 'b,d,e,g,h,l,m,n,o,p,q,r,u,x,3,4', 'b,g,h,q,r,t,u,x,z,3', 'd,e,g,h,n,o,r,u,x,z,3',NA,'d,g,h,k,l,m,n,p,t,u,z,3', 'b,g,h,k,l,n,o,q,r,s,t,u,y,1,3,4',
    'g,h,k,m,n,o,p,r,s,t,u,x,y,z,3,4'
  )

Q5_1_df = multipleChoiceExp(choicesQ5_1,"Q5_1",lvls)
Q5_1_freq = sumFeature(Q5_1_df, 
                       c("Q5_1.a","Q5_1.b","Q5_1.c","Q5_1.d","Q5_1.e","Q5_1.f","Q5_1.g","Q5_1.h","Q5_1.i","Q5_1.j",
                         "Q5_1.k","Q5_1.l","Q5_1.m","Q5_1.n","Q5_1.o","Q5_1.p","Q5_1.q","Q5_1.r","Q5_1.s","Q5_1.t",
                         "Q5_1.u","Q5_1.v","Q5_1.w","Q5_1.x","Q5_1.y","Q5_1.z","Q5_1.1","Q5_1.2","Q5_1.3","Q5_1.4"
))

##### M Choice Q5.2 : Type of sports recommendation level "with adequate training" after TKA
choicesQ5_2 = 
  c('f,l,w,y,z,1,2', 'a,b,d,e,g,h,l,m,n,o,p,q,r,s,t,u,x,z,3,4', 'c,e,k,l,m,q,s,i,w,y', 'g,h', 'a,f,i,j,l,p,v,w,y,2', 'c,f,s', 'b,e,h,n,p,t,x,z,1,4', 'b,d,e,h,k,m,n,o,p,q,r,t,u,,v,w,x,y,z,1,2,3', 'b,h,k,l,o,p,s,w,y,1,4', 'a,e,j,k,l,o,p,r,w,y,z,1,2,4', 
    NA, 'c,ks,v,y,1,2', 'd,e,k,l,o,p,q,s,t,v,w,y,z,1,4', 'a,c,f,i,j,l,s,v,w,1,2', 'd,e,j,l,q,s,w,y,z,1', 'e', 'd,e,j,k,p,q,t,w,y,z,1', 'a,c,e,f,h,i,j,m,o,p,q,r,s,t,v,w,x,y,z,1,2,4', 'c,j,s,w,y,z,1', NA, 
    'f,s,z,1', 'e,g,c,m,n,o,p,s,v,w,x,y,z,1,3,4', 'a,b,d,e,g,m,t,y,z,4', 'd,e,g,j,k,l,m,p,q,s,w,x,y,z,1,2,3,4', 'a,c,i,j,l', 'b,d,e,g,h,k,m,n,q,r,x,y,z,1,3,4', 'a,b,d,g,h,m,p,t,w,x,y,z,1', 'a,g,m,w,1,2', 'a,c,d,e,f,i,j,l,s,v,4', NA,
    'a,b,c,f,l,y,1', NA, 'a,b,c,f,i,j,l,s,v,w,y,1,2,4', 'b,g,h,k,m,o,p,z,4', NA, 'a,c,l,s,w,y,z,1,2', 'd,j,l,s,t,y,z,1', 'a,b,c,d,e,f,g,i,j,l,p,s,v,w,y,z,1,2', 'b,e,h,l,m,q,w,z,1,2,4', 'b,d,g,h,k,o,p,s,x,y,z,2',
    'a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4', 'e,z', 'b,f,h,i,j,p,q,s,w,y,z,4', 'd,e,o,p,q,s,z', 'c', NA, 'a,b,f,i,j,l,s,t,w,x,y,z,1,2', 'a,c,f,i,j,v,y,2', 'b,i,j,k,l,p,x,1,2,4', 'a,c,e,i,j,l,s,u,y,z,1,2',
    'b,c,d,e,f,g,h,i,j,k,l,m,o,p,q,s,t,v,w,y,z,1,2,4', 'b,d,e,g,m,p,q,s,x,y,z,4', 'e,h,j,r,s,t,w,y,z,2,4', NA, 'd,j,p,s', 'b,c,d,e,f,g,h,j,k,l,m,n,o,p,q,r,s,t,u,v,x,y,z,1,3,4', 'a,c,k,p,q,s,y,1', 'e,j,m,p,s,v,w,y,z', 'a,c,e,f,i,j,k,l,o,s,v,w,1,2,4', 'a,e,g,h,o,p,q,r,s,t,x,y,z,2,4',
    NA, 'c,m,s,y,z,4', 'd,e,l,q,w', 'a,b,d,f,h,i,j,o,p,q,r,s,v,w,y,z,1,2', 'a,b,d,f,i,j,k,o,p,q,s,v,w,x,y,z,1,2', 'a,e,f,i,j,l,m,o,s,v,w,y,1,2', 'c,e,k,l,q,w,1,4', 'a,c,e,f,i,j,k,o,p,s,v,y,1,2', 'a,b,d,e,k,m,o,q,r,w,y,1,4', 'b,e,m,p,v,w,1',
    NA, NA, 'b,e,g,h,s,x,y,z', 'b,d,g,l,p,q,r,y,z,1,2', 'g,i,j,s,t,v,w,x,y,z,1,2,3,4', NA, 'NA', 'e,h,k,o,p,s,z,3,4', 'b,d,e,g,h,l,m,o,p,s,t,w,x,1', 'a,b,d,e,g,i,j,k,l,q,v,w,x,y,z,1,2',  
    'b,d,e,h,l,p,s,t,w,y,z', 'a,c,e,h,s,v,y,1,2', 'b,m,w', NA, NA, 'e,k,m,q,4', 'e,l,m,p,q,s,w,y,z', 'a,i,j,s,t,y,1,2', 'a,c,f,i,j,l,q,s,v,w,y,1,2', 'a,c,l,q,s,w,y,1,2',
    'e,f,l,m,p,q,s,t,y,z,1,4', 'a,c,e,f,i,k,m,o,t,v,y,z,2,4', 'a,b,d,e,k,l,p,s,w,y,z,2', 'k', 'k,s,t,w,1,2', 'a,e,f,i,j,k,l,m,n,o,p,s,v,w,y,1,2,4', 'a,b,f,i,j,k,l,m,q,s,t,v,y,2,4','a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,1,2,3,4','a,b,c,e,f,i,j,o,q,r,s,v,w,x,y,1,2,4', 'a,d,e,f,i,j,m,v,w,x,z,2',
    'b,c,d,el,w,1'
  )

Q5_2_df = multipleChoiceExp(choicesQ5_2,"Q5_2",lvls)
Q5_2_freq = sumFeature(Q5_2_df, 
                       c("Q5_2.a","Q5_2.b","Q5_2.c","Q5_2.d","Q5_2.e","Q5_2.f","Q5_2.g","Q5_2.h","Q5_2.i","Q5_2.j",
                         "Q5_2.k","Q5_2.l","Q5_2.m","Q5_2.n","Q5_2.o","Q5_2.p","Q5_2.q","Q5_2.r","Q5_2.s","Q5_2.t",
                         "Q5_2.u","Q5_2.v","Q5_2.w","Q5_2.x","Q5_2.y","Q5_2.z","Q5_2.1","Q5_2.2","Q5_2.3","Q5_2.4"
))


##### Multiple Choice Q5.3 : Type of sports recommendation level "not recommended" after TKA
choicesQ5_3 = 
  c('a,c,i,j,v', 'a,c,e,f,i,j,k,u,v,w,y,1,2', 'a,f,i,v,2', 'a,c,f,i,j,k,l,s,v,w,y,z,1,2', 'c,1', 'k', 'a,c,f,i,j,k,l,o,s,v,w,y,z', 'a,c,f,i,l,s,4', 'a,c,f,i,j,m,v,y,z,2', 'c,f,i,s', 
    NA, NA, 'a,c,e,f,i,j,l,o,s,v,y,z,2', NA, 'a,c,f,i', 'a,c,d,f,h,i,j,k,l,p,s,v,w,y,1,2', 'a,c,f,i,l,s,v,2', 'k,l', 'a,f,i,v,2', 'c', 
    'a,c,i,j,k,v,w,y,2', 'a,c,f,i,j,k', 'c,f,i,j,l,s,v,w,1,2', 'a,c,f,i,v', NA, 'a,c,f,i,j,l,o,p,s,t,u,w,2', 'c,f,i,j,l,s,v,2', 'c,d,f,i,j', NA, NA,
    'i,j,v,w,2', NA, NA, 'a,c,d,e,f,i,j,l,q,s,t,v,w,y,1,2', 'c,f,i,s', 'f,i,k,v', 'a,c,f,i,k,v,2', NA, 'a,c,f,i,j,k,s,v,y', 'a,c,f,i,j,l,q,v,w,1',
    NA, 'a,c,f,i,j,l,p,s,t,v,w,y,1,2', 'a,c,v,1,2', 'a,c,f,i,j,k,l,v,w,y,1,2', NA, NA, 'v', NA, 'a,c,f', NA,
    'a', 'a,c,f,i,j,k,l,v,w,1,2', 'a,c,f,i,j,v,y,z,1,2', 'c,f,v', 'a,c,e,f,i,l,v,y,1,2', 'a,i,w,2', 'f,i,j,l,v,w,2', 'a,c,f,i,l,1,2', NA, 'c,f,i,j,k,l,v,w,1',
    'a,c,e,f,i,j,k,l,s,v,w,y,z,1,2', 'a,f,i,j,k,l,v,2', 'a,c,f,i,j,k,p,s,t,v,y,z,1,2', 'c,e,l', 'c,l', 'c', 'a,v', NA, 'c,i,j,l,p,s,vv,z,2', 'a,c,f,i,j,k,l',
    NA, 'a,f,ij,k,l,s,v,w,2', 'a,c,d,f,i,j,l,p,q,v,w,1,2', 'a,c,e,f,i,j,o,s,v,w', 'a,c,d,f,l', NA, 'a,b,c,d,f,i,j,l,q,v,w,y,1,2', 'a,c,f,i,j,k,q,v,y,z,2', 'c,f,s', 'a,c,f,i,j,k,v,1,4',  
    'a,c,f,i,j,k,v,1,4', 'f,i,j', 'a,c,f,i,j,k,l,s,v,y,z,1,2', NA, 'a,c,f,i,j,k,l,v,w,z,1,2', 'a,b,c,d,f,i,j,l,o,p,s,v,w,y,z,1,2', 'a,c,f,i,j,v,1,2', 'c,d,f', NA, 'f,i,j,v',
    'i,j,v,w', 'j,l,p,s,w,1', 'c,f,i,j,v,1', 'a,c,f,i,j,v,y', 'a,c,f,i,j,v,y,z', 'c,d', 'c,p,q,1','b', NA, 'c,p',
    'a,f,i,j,q,v,2'
  )

Q5_3_df = multipleChoiceExp(choicesQ5_3,"Q5_3",lvls)
Q5_3_freq = sumFeature(Q5_3_df, 
                       c("Q5_3.a","Q5_3.b","Q5_3.c","Q5_3.d","Q5_3.e","Q5_3.f","Q5_3.g","Q5_3.h","Q5_3.i","Q5_3.j",
                         "Q5_3.k","Q5_3.l","Q5_3.m","Q5_3.n","Q5_3.o","Q5_3.p","Q5_3.q","Q5_3.r","Q5_3.s","Q5_3.t",
                         "Q5_3.u","Q5_3.v","Q5_3.w","Q5_3.x","Q5_3.y","Q5_3.z","Q5_3.1","Q5_3.2","Q5_3.3","Q5_3.4"
))

##### M Choice Q5.4 : Type of sports recommendation level "undecided" after TKA

choicesQ5_4 = 
  c(NA, NA, NA, 'b,d,e', NA, NA, 'd', NA, NA, 'v', 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, 'k', 
    NA, NA, NA, NA, 'v', NA, NA, NA, NA, NA,
    NA, NA, NA, NA, NA, 'j', NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
    'h', '1', NA, NA, NA, 'd', NA, NA, NA, NA,
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,  
    NA, NA, NA, NA, 's,y', NA, NA, NA, NA, NA,
    'a,c,2', NA, NA, NA, NA, NA, NA, NA, NA, NA,
    NA
  )

Q5_4_df = multipleChoiceExp(choicesQ5_4,"Q5_4",lvls)
Q5_4_freq = sumFeature(Q5_4_df, 
                       c("Q5_4.a","Q5_4.b","Q5_4.c","Q5_4.d","Q5_4.e","Q5_4.f","Q5_4.g","Q5_4.h","Q5_4.i","Q5_4.j",
                         "Q5_4.k","Q5_4.l","Q5_4.m","Q5_4.n","Q5_4.o","Q5_4.p","Q5_4.q","Q5_4.r","Q5_4.s","Q5_4.t",
                         "Q5_4.u","Q5_4.v","Q5_4.w","Q5_4.x","Q5_4.y","Q5_4.z","Q5_4.1","Q5_4.2","Q5_4.3","Q5_4.4"
))

# extract the pure numerical values
Q5_1_vec = as.vector(Q5_1_freq)
Q5_2_vec = as.vector(Q5_2_freq)
Q5_3_vec = as.vector(Q5_3_freq)
Q5_4_vec = as.vector(Q5_4_freq)

groupNames = c("Basketball","Bowling","Boxing","E-Scooter","Fitness/Weights",
               "Soccer","Ballroom","Golf","Handball","Hockey","Jogging",
               "Climbing","Pilates","Biking level","Biking cross","Horseback",
               "Rowing","Swimming","Ski slope","Ski long","Walking",
               "Squash","Surfing","Dancing","Tennis","Table tennis","Gymnastics","Volleyball",
               "Hiking","Yoga")
tempLabels = c("Type","Count","Recommendation")

Q5_1_df = data.frame(groupNames, Q5_1_vec)
Q5_1_df['Recommendation'] = "4. Without limitations"
colnames(Q5_1_df) = tempLabels

Q5_2_df = data.frame(groupNames, Q5_2_vec)
Q5_2_df['Recommendation'] = "3. With training"
colnames(Q5_2_df) = tempLabels

Q5_3_df = data.frame(groupNames, Q5_3_vec)
Q5_3_df['Recommendation'] = "2. Not recommended"
colnames(Q5_3_df) = tempLabels

Q5_4_df = data.frame(groupNames, Q5_4_vec)
Q5_4_df['Recommendation'] = "1. Undecided"
colnames(Q5_4_df) = tempLabels

Q5_df = rbind(Q5_1_df,Q5_2_df,Q5_3_df,Q5_4_df)
Q5_df = Q5_df[order(Q5_df["Type"]),]
row.names(Q5_df) <- 1:nrow(Q5_df)

# Figure 7: Specific activity recommendations after THA, y-axis: numbers as absolute counts, x-axis: type of activity/sport (Ballroom was abbreviated for ballroom dancing). Recommendations ‘without limitations’ (dark grey), ‘with adequate training’ (medium grey), ‘not recommended’ (light grey), ‘undecided’ (lightest grey). 
# Q5 HP: Sport Empfehlung nach Knie-TEP
ggp <- ggplot(Q5_df,aes(x=Type, y=Count, fill=Recommendation), position="stack", stat='identity') + xlab("Activity") + 
  ylab("Counts") + labs(fill = "Recommendation") + ggtitle("Activity Recommendation after TKA") + customPlot
ggp + geom_col() + scale_fill_grey(start=0.8, end=0.2) + theme(axis.text.x = element_text(angle = 45, hjust = 1)) +  theme(legend.position = "bottom") +
  scale_y_continuous(limits = c(0,100)) + labs(tag="") + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)

ggsave(paste(path, "Q5-Histogram.pdf"), width=10, height=5)
################################################################################################################################################################
################################################################################################################################################################

#Figure A1: Plot recommendations from Q4 (THA) + Q5 (TKA) next to each other for better comparison.
Q4_df$ptype = 'H'
Q5_df$ptype = 'K'
Q6_df = rbind(Q4_df, Q5_df)
Q6_df = Q6_df[order(Q6_df["Type"]),]
row.names(Q6_df) <- 1:nrow(Q6_df)

ggp <- ggplot(Q6_df,aes(x=ptype, y=Count, fill=Recommendation), position="stack", stat='identity') + xlab("Activity") + ylab("Counts") + 
  labs(fill = "Recommendation") + ggtitle("Comparison Activity Recommendation after THA vs. TKA") + customPlot + facet_grid(~ Type)
ggp + geom_col() + scale_fill_grey(start=0.8, end=0.2) + theme(axis.text.x = element_text(angle = 45, hjust = 1, size=12)) +  theme(legend.position = "bottom") +
  scale_y_continuous(limits = c(0,100)) + labs(tag="") + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)

ggsave(paste(path, "Q6-Histogram.pdf"), width=30, height=10)
################################################################################################################################################################
################################################################################################################################################################

#Plots for all non-MC questions below:
# ID
ID <- 1:length(Q1_1)

# printing the rows to verify
# DEPRECATED: use the dataframe version to check
# ID
# length(ID)
# Q1_1
# length(Q1_1)
# definining data frame

dataframe <- data.frame(
  "ID" = ID, "Q1.1" = Q1_1, "Q1.2" = Q1_2, "Q1.3" = Q1_3, "Q3.1" = Q3_1, "Q3.2" = Q3_2, "Q3.3" = Q3_3, "Q3.4" = Q3_4, 
  "Q3.5" = Q3_5, "Q3.6" = Q3_6, "Q3.7" = Q3_7, "Q3.8" = Q3_8, "Q3.9" = Q3_9 , "Q3.11" = Q3_11, 
  "Q3.12" = Q3_12, "Q3.13" = Q3_13
  )

# print(dataframe)
# for validation
# dataframe[, c("ID", "Q1.1")]

# prefix for path
path <- "~/orchid/"
# path <- dirname(sys.frame(1)$ofile)

# General formatting string for plots
customPlot <- list(
  scale_colour_tableau(),
  theme(plot.title = element_text(face="bold", hjust = 0.5)
        ) 
)

customPlotHist <- list(
  geom_text(aes(y = (..count..),label = ifelse((..count..)==0,"",scales::percent((..count..)/sum(..count..)))), stat="count", vjust=-0.5) #, position=position_dodge()) #nudge_y=2.0)
)

# Q1.1: Plotting: Jahr der Approbation 
ggp <- ggplot(data.frame(dataframe[,"Q1.1"]), aes(x=dataframe[,"Q1.1"])) + xlab("Year") + ylab("Counts [%]") + 
  ggtitle("Distribution: Year of Approbation") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q1_1-Histogram.pdf"), width=4.5, height=5)

# Q1.2: Plotting: Sportliche Aktivität des Umfrage Teilnehmers
ggp <- ggplot(data.frame(dataframe[,"Q1.2"]), aes(x=dataframe[,"Q1.2"])) + xlab(" ") + ylab("Counts[%]") + 
  ggtitle("Athletic Activity Level") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1)) + scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q1_2-Histogram.pdf"), width=3, height=5)

# Q1.3: Sportliche Aktivität als Standard Frage
ggp <- ggplot(data.frame(dataframe[,"Q1.3"]), aes(x=dataframe[,"Q1.3"])) + xlab("Included") + ylab("Counts [%]") + 
  ggtitle("Patient Assessment", subtitle="Physical Activity") + customPlot
ggp + geom_bar() + scale_y_continuous(limits = c(0,100)) + customPlotHist + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)

ggsave(paste(path, "Q1_3-Histogram.pdf"), width=2.25, height=5)

# Q1.4 MC Question #
# Q1.5 MC Question # 

#Q3.1: Wichtigkeit von sportlicher Aktivität nach Knie-TEP = Importance of athletic activity after TKA
  ggp <- ggplot(data.frame(dataframe[,"Q3.1"]), aes(x=dataframe[,"Q3.1"])) + xlab(" ") + ylab("Counts[%]") + 
    ggtitle("Importance of Sports after TKA          ", subtitle="Surgeon's Assessment") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_1-Histogram.pdf"), width=3.75, height=5)

#3.2: Negativeinfluss sportlicher Aktivität auf die Haltbarkeit einer Knie-TEP = Negative influence of sporting activity on the 
ggp <- ggplot(data.frame(dataframe[,"Q3.2"]), aes(x=dataframe[,"Q3.2"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("Negative Effect of Athletic Activity", subtitle="On TKA Longevity") + customPlot
ggp + geom_bar() + customPlotHist + scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_2-Histogram.pdf"), width=3, height=5)

#3.3 Positiveinfluss sportlicher Aktivität auf die Haltbarkeit einer Knie-TEP
ggp <- ggplot(data.frame(dataframe[,"Q3.3"]), aes(x=dataframe[,"Q3.3"])) + xlab("Assessment") + ylab("Counts [%]") + 
  ggtitle("Positive Effect of Athletic Activity", subtitle="On TKA Longevity") + customPlot
ggp + geom_bar() + customPlotHist + scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_3-Histogram.pdf"), width=3, height=5)

#3.4 Einschätzung des Belastungsgrads der Knie-TEP durch Patienten
ggp <- ggplot(data.frame(dataframe[,"Q3.4"]), aes(x=dataframe[,"Q3.4"])) + xlab("Responses") + ylab("Counts [%]") + 
  ggtitle("Patient-Induced Stress on TKA") + labs(tag="A") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_4-Histogram.pdf"), width=4.5, height=5)

# Q3.5: Häufigkeit von Revisionen aufgrund von Überbelastung / Sport = Frequency of sports-associated revision surgery
ggp <- ggplot(data.frame(dataframe[,"Q3.5"]), aes(x=dataframe[,"Q3.5"])) + xlab("Responses") + ylab("Counts [%]") + 
  ggtitle("Sports-Associated Revision Surgery") + labs(tag="B") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_5-Histogram.pdf"), width=4.5, height=5)

# Q3.6: Wahl des operativen Zugangswegs bei hoher sportlicher Belastung = Choice of surgical approach in patients with high sporting activity after TKA
ggp <- ggplot(data.frame(dataframe[,"Q3.6"]), aes(x=dataframe[,"Q3.6"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("Surgical Approach for TKA", subtitle="Surgeons' Preference") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 0, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_6-Histogram.pdf"), width=4.5, height=5)

# Q3.7: Wahl des Alignments = Choice of alignment in patients with high sporting activity after TKA
ggp <- ggplot(data.frame(dataframe[,"Q3.7"]), aes(x=dataframe[,"Q3.7"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("Preferred TKA Alignment") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + labs(tag="A") + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_7-Histogram.pdf"), width=3.75, height=5)

#3.8 Ziehen sie bei hoher sportlicher Beanspruchung eine unikondyläre Schlittenprothese zu bikondylären Endoprothese vor? = 
ggp <- ggplot(data.frame(dataframe[,"Q3.8"]), aes(x=dataframe[,"Q3.8"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("BKA or UKA?") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_8-Histogram.pdf"), width=2.25, height=5)

#3.9 Glauben Sie, dass das Design Ihrer Knie-TEP Einfluss auf die Sportfähigkeit hat? 
#= Do high RTS expectations influence the choice of TKA design?
ggp <- ggplot(data.frame(dataframe[,"Q3.9"]), aes(x=dataframe[,"Q3.9"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("TKA Design") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  labs(tag="B") + scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_9-Histogram.pdf"), width=5.25, height=5)

#3.10 MC Question #

#3.11 Anlage von Schmerzkathetern bei hohem sportlichen Anspruch 
#= Use of pain catheters in patients with high RTS expectations after TKA
ggp <- ggplot(data.frame(dataframe[,"Q3.11"]), aes(x=dataframe[,"Q3.11"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("Postoperative Pain Catheter") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  labs(tag="A") + scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_11-Histogram.pdf"), width=3.2, height=5)

#3.12 Nachbehandlung = Rehabilitation after TKA in patients with high RTS expectations
ggp <- ggplot(data.frame(dataframe[,"Q3.12"]), aes(x=dataframe[,"Q3.12"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("Postoperative Treatment") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + labs(tag="B") + scale_fill_grey(start=0.8, end=0.2) + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_12-Histogram.pdf"), width=3.75, height=5)

#3.13 Empfehlung nach Knie-TEP zu high-impact Sportarten = Recommendations for high-impact sports after TKA
ggp <- ggplot(data.frame(dataframe[,"Q3.13"]), aes(x=dataframe[,"Q3.13"])) + xlab("") + ylab("Counts [%]") + 
  ggtitle("High-Impact Sports after TKA", subtitle="") + customPlot
ggp + geom_bar() + customPlotHist + theme(axis.text.x = element_text(angle = 22.5, hjust = 1, size=12)) + 
  scale_y_continuous(limits = c(0,100)) + scale_fill_grey(start=0.8, end=0.2) + labs(tag="A") + theme(
  panel.background = element_rect(fill = "#FFFFFF", colour = "#FFFFFF",
                                  size = 2, linetype = "solid"),
  panel.grid.major = element_line(size = 0.25, linetype = 'solid',
                                  colour = "grey75"), 
  panel.grid.minor = element_line(size = 0.1, linetype = 'solid',
                                  colour = "grey75")
)
ggsave(paste(path, "Q3_13-Histogram.pdf"), width=5, height=5)

#Q3.14 MC Question# 

#Q5 MC QUestion #

######End Data Frame############################################################################################################################################
################################################################################################################################################################
